;- Little-Timpetu, ein simples Schachprogramm
;- "Helle" Klaus Helbing, aktualisiert 04.12.2016, PB5.50 (x64)

;- Einige Fachbegriffe:
;-- Halbzug: Ist der Zug, den eine Seite (Weiss oder Schwarz) ausfhrt. Beginnt eine Partie 
;--  z.B. so: Weiss zieht Bauer von E2 nach E4 und Schwarz antwortet mit Bauer von E7 nach E5,
;--  so ist Bauer von E2 nach E4 ein Halbzug und Bauer von E7 nach E5 ist ebenfalls ein Halbzug.
;-- Pondern, Permanent Brain: Das Programm rechnet auch an der Stellung, wenn der Gegner am
;--  Zug ist. Macht der Gegner tatschlich den vom Programm errechneten Zug, hat es einen Zeit-
;--  vorteil, den es zur weiteren Rechen-Vertiefung nutzen kann.  
;-- Nullmove: Whrend der Suche verzichtet eine Seite darauf, seinen Zug auszufhren, die andere
;--  Seite kann also praktisch 2 Zge hintereinander machen. Reicht dies nicht aus um Vorteil zu
;--  erlangen, kann man annehmen, das der erste dieser beiden Zge Mist war und diese Linie muss
;--  nicht weiter berechnet werden. 
;-- Hashtabelle: Dort werden Werte bereits berechneter Stellungen abgespeichert und brauchen so
;--  bei Wiederauftreten nicht wieder zeitaufwndig berechnet werden. 
;-- Ruhesuche: Ist die vorgegebene Suchtiefe erreicht wird normalerweise abgebrochen und (wenn
;--  vorhanden) mit dem nchsten Zug weitergerechnet. Ein Abbruch wre aber schlecht, wenn z.B.
;--  gerade Schach geboten wurde oder eine Figur geschlagen wurde. Deshalb wird in solchen Fllen
;--  die Suche fortgesetzt (Ruhesuche, bis die Stellung sich "beruhigt" hat), allerdings werden
;--  dann nicht mehr alle mglichen Zge untersucht, sondern nur Schlagzge und Bauernumwandlungen.
;- Alpha-Beta: Verfeinerter Minimax-Suchalgorithmus; das Programm verzichtet auf die Berechnung
;-- von Stellungen, die der Gegner (wenn er optimiert spielt) sowieso nicht herbeifhren wird.

;- Einschrnkungen:
;-- Programm hat immer Schwarz
;-- Programm hat feste Bedenkzeit (3 Sekunden, nderbar)
;-- keine Hashtabellen
;-- kein Pondern (Permanent Brain)
;-- kein Nullmove
;-- nur eine Attackfeld-Tabelle
;-- nur einfache Bewertungsfunktion
;-- pro Farbe nur ein Zuggenerator
;-- kein Test auf Stellungswiederholung
;-- keine 50-Zge-Regel
;-- Bauernumwandlung nur in Dame
;-- keine Anzeigen, kein Men

;Das Programm arbeitet intern mit einem "Schachbrett" mit 10*12 Feldern. Das eigentliche
;8*8 Schachbrett ist darin so eingebettet, dass oben und unten jeweils 2 Zusatzfelder und
;links und rechts je 1 Zusatzfeld es umrahmen. Feld-Nr.21 entspricht also dem "normalen"
;Feld A8 und Feld-Nr.98 entspricht H1. Diese Randfelder sind fr die Zugerzeugung ntig;
;ist das Zielfeld eines Figuren-Zuges eines dieser Randfelder, ist es ein ungltiger Zug 
;und wird nicht in die Zugliste aufgenommen. Wegen der Springerzge sind 2 Randfelder ntig,
;damit nicht ein Zugriff auf Speicherbereiche ausserhalb des Schachbrettes (oben und unten)
;erfolgt bzw. doch ein gltiges Feld (links und rechts) erwischt wird (links und rechts je
;ein Randfeld schaffen die ntige Distanz von 2).  
;Alle Felder mssen natrlich Werte besitzen. Jedes Feld wird als Byte in einer Structure
;aufgefasst. Zur besseren bersicht werden die Werte hexadezimal dargestellt. Die zustzlichen
;Randfelder erhalten den Wert $8, ein weisses Leerfeld den Wert $00 und ein schwarzes Leerfeld
;$40. Diese $00 und $40 sind auch Werte-Bestandteil aller anderen regulren Feld-(Figuren-)Werte.
;Die Figuren sind folgendermassen codiert:
;- Bauer    = $1
;- Springer = $2
;- Lufer   = $3
;- Turm     = $4
;- Dame     = $5
;- Knig    = $6
;Dazu kommt dann die Figurenfarbe: $10 fr weisse Figur und $80 fr schwarze Figur.
;Wurde eine Figur im Verlaufe der Partie gezogen kommt der Wert $20 hinzu (Gltigkeit Rochade!)
;Bit-mssig ist ein Feld-Byte also so aufgebaut:
;       +---+---+-------+---+---+---+---+  
;  Bit  | 7 | 6 | 5 | 4 | 3 | 2 | 1 | 0 | 
;  Wert |$80|$40|$20|$10|$08|$04|$02|$01|
;       +---+---+---+---+---+---+---+---+
;Bit 0-2 : Figurenart; Wert 0 = keine Figur, andere Werte s.o. 
;Bit   3 : Randfeld, Wert $08
;Bit   4 : Figurenfarbe, wenn gesetzt ($10) weisse Figur
;Bit   5 : Ob Figur auf dem Feld schon gezogen; wenn ja Wert $20
;Bit   6 : Feldfarbe, weiss = $00; schwarz = $40
;Bit   7 : Figurenfarbe, wenn gesetzt ($80) schwarze Figur
;2 Bits fr die Figurenfarbe erleichtern die Erkennung.
;Beispiel fr ein Feld mit Figur: $C5 = %11000101 : 
;- Bit 7 gesetzt       -> $80 = %10000000 = schwarze Figur
;- Bit 6 gesetzt       -> $40 = %01000000 = schwarzes Feld
;- Bit 5 nicht gesetzt -> $00 = %00000000 = Figur wurde noch nicht gezogen  
;- Bit 4 nicht gesetzt -> $00 = %00000000 = keine weisse Figur (na klar!)
;- Bit 3 nicht gesetzt -> $08 = %00000000 = kein Randfeld (auch klar)
;- Bit 2 und 0 gesetzt -> $05 = %00000101 = Figuren-Wert = 5 = Dame
;Es ist also eine schwarze Dame auf einem schwarzem Feld und wurde noch nicht gezogen. 
;10*12-Brettdarstellung, Grundstellung, Schwarz oben, Weiss unten
;           +---------------------------------------+
; Feld-Nr.  |000|001|002|003|004|005|006|007|008|009|
; Wert      |$08|$08|$08|$08|$08|$08|$08|$08|$08|$08|
;           +---+---+---+---+---+---+---+---+---+---+
;           |010|011|012|013|014|015|016|017|018|019|
;           |$08|$08|$08|$08|$08|$08|$08|$08|$08|$08|
;           +---+---+---+---+---+---+---+---+---+---+
;        8  |020|021|022|023|024|025|026|027|028|029|
;           |$08|$84|$C2|$83|$C5|$86|$C3|$82|$C4|$08|
;           +---+---+---+---+---+---+---+---+---+---+
;        7  |030|031|032|033|034|035|036|037|038|039|
;           |$08|$C1|$81|$C1|$81|$C1|$81|$C1|$81|$08|
;           +---+---+---+---+---+---+---+---+---+---+
;        6  |040|041|042|043|044|045|046|047|048|049|
;           |$08|$00|$40|$00|$40|$00|$40|$00|$40|$08|
;           +---+---+---+---+---+---+---+---+---+---+
;        5  |050|051|052|053|054|055|056|057|058|059|
;           |$08|$40|$00|$40|$00|$40|$00|$40|$00|$08|
;           +---+---+---+---+---+---+---+---+---+---+
;        4  |060|061|062|063|064|065|066|067|068|069|
;           |$08|$00|$40|$00|$40|$00|$40|$00|$40|$08|
;           +---+---+---+---+---+---+---+---+---+---+
;        3  |070|071|072|073|074|075|076|077|078|079|
;           |$08|$40|$00|$40|$00|$40|$00|$40|$00|$08|
;           +---+---+---+---+---+---+---+---+---+---+
;        2  |080|081|082|083|084|085|086|087|088|089|
;           |$08|$11|$51|$11|$51|$11|$51|$11|$51|$08|
;           +---+---+---+---+---+---+---+---+---+---+
;        1  |090|091|092|093|094|095|096|097|098|099|
;           |$08|$54|$12|$53|$15|$56|$13|$52|$14|$08|
;           +---+---+---+---+---+---+---+---+---+---+
;           |100|101|102|103|104|105|106|107|108|109|
;           |$08|$08|$08|$08|$08|$08|$08|$08|$08|$08|
;           +---+---+---+---+---+---+---+---+---+---+
;           |110|111|112|113|114|115|116|117|118|119|
;           |$08|$08|$08|$08|$08|$08|$08|$08|$08|$08|
;           +---+---+---+---+---+---+---+---+---+---+
;                 A   B   C   D   E   F   G   H
;Bewertungswert: $8000 bedeutet vollkommene Ausgeglichenheit (Weiss und Schwarz stehen gleich gut).
; Ist ein Bewertungs-Merkmal (Material, Stellungsbewertung) fr Weiss gut, wird dieser Wert zu-
; addiert, ansonsten subtrahiert. Der Wert $F532 (und sein "Negativ" $0ACE) sind (relativ) frei
; gewhlt; Werte grsser/gleich als $F500 signalisieren ein (mgliches) Matt, die $32 = 50dez
; rhren noch von der ursprnglich mal angedachten maximalen Suchtiefe her. 
   Global ZZG.q
   Global ZST.q
Global BGFarbe.l                       ;fr optische Darstellung wer am Zug
Global ZugZeit.l = 3000                ;3 Sekunden Rechenzeit fr das Programm pro Zug
Global Time.l 
Global TimeOut.l
Global ZZ.l                            ;Zeiger in Zugtabelle zum Schreiben
Global AZ.l                            ;Abstand in Zugtabelle fr die Halbzge
Global Attack.l                        ;Merker fr attackiertes Feld
Global Tiefe.l                         ;aktuelle Suchtiefe
Global RuSu.l                          ;Merker fr Ruhesuche   
Global RochStatusW.l                   ;Merker, welche Rochade evtl. ausgefhrt wurde
Global RochStatusS.l
Global MPW.l                           ;materiell-positionieller Wert (Stellungsbewertung) 
Global Endspiel.l                      ;Merker ob Endspiel 
Global XL.l                            ;Hilfs-Variable
Global YL.l
Global ZL.l

Global VB.a                            ;Hilfs-Variable
Global WB.a
Global XB.a
Global YB.a
Global ZB.a

Global Color.a                         ;welche Farbe am Zug ist
Global AFeldZ.a                        ;Ausgangsfeld fr Zugtabelle schreiben und Attackfeld
Global ZFeldZ.a                        ;Zielfeld fr Zugtabelle schreiben und Attackfeld

Global WLastZugA.a                     ;Ausgangsfeld letzter weisser Zug
Global WLastZugZ.a                     ;Zielfeld letzter weisser Zug
Global SLastZugA.a                     ;Ausgangsfeld letzter schwarzer Zug
Global SLastZugZ.a                     ;Zielfeld letzter schwarzer Zug
Global WKFeld.a = 95                   ;Feld des weissen Knigs in der Grundstellung
Global SKFeld.a = 25                   ;Feld des schwarzen Knigs in der Grundstellung
Global WKLinie.a = 5                   ;Linie, auf der Knig steht; 5=E-Linie
Global SKLinie.a = 5

OpenWindow(0, 0, 0, 335, 335, "Little-Timpetu, Helles simples Schachprogramm 0.1", #PB_Window_SystemMenu | #PB_Window_ScreenCentered); And CreateGadgetList(WindowID(0))

UsePNGImageDecoder()                   ;die Images der Figuren und Felder sind im PNG-Format
;Images (Figuren und Leerfelder) laden
Global LD=CatchImage(0, ?LD)           ;dunkles Leerfeld
Global LH=CatchImage(1, ?LH)           ;helles Leerfeld
Global WBD=CatchImage(2, ?WBD)         ;weisser Bauer auf dunklem Feld
Global WBH=CatchImage(3, ?WBH)         ;weisser Bauer auf hellem Feld
Global WSD=CatchImage(4, ?WSD)         ;weisser Springer auf dunklem Feld
Global WSH=CatchImage(5, ?WSH)         ;weisser Springer auf hellem Feld
Global WLD=CatchImage(6, ?WLD)         ;weisser Lufer auf dunklem Feld
Global WLH=CatchImage(7, ?WLH)         ;weisser Lufer auf hellem Feld
Global WTD=CatchImage(8, ?WTD)         ;weisser Turm auf dunklem Feld
Global WTH=CatchImage(9, ?WTH)         ;weisser Turm auf hellem Feld
Global WDD=CatchImage(10, ?WDD)        ;weisse Dame auf dunklem Feld
Global WDH=CatchImage(11, ?WDH)        ;weisse Dame auf hellem Feld
Global WKD=CatchImage(12, ?WKD)        ;weisser Knig auf dunklem Feld
Global WKH=CatchImage(13, ?WKH)        ;weisser Knig auf hellem Feld
Global SBD=CatchImage(14, ?SBD)        ;schwarzer Bauer auf dunklem Feld
Global SBH=CatchImage(15, ?SBH)        ;schwarzer Bauer auf hellem Feld
Global SSD=CatchImage(16, ?SSD)        ;schwarzer Springer auf dunklem Feld
Global SSH=CatchImage(17, ?SSH)        ;schwarzer Springer auf hellem Feld
Global SLD=CatchImage(18, ?SLD)        ;schwarzer Lufer auf dunklem Feld
Global SLH=CatchImage(19, ?SLH)        ;schwarzer Lufer auf hellem Feld   
Global STS=CatchImage(20, ?STD)        ;schwarzer Turm auf dunklem Feld   STS=STD wegen Asm
Global STH=CatchImage(21, ?STH)        ;schwarzer Turm auf hellem Feld  
Global SDD=CatchImage(22, ?SDD)        ;schwarze Dame auf dunklem Feld
Global SDH=CatchImage(23, ?SDH)        ;schwarze Dame auf hellem Feld
Global SKD=CatchImage(24, ?SKD)        ;schwarzer Knig auf dunklem Feld
Global SKH=CatchImage(25, ?SKH)        ;schwarzer Knig auf hellem Feld   

;---------------------------- S T R U K T U R E N -------------------------------------------------
;zur besseren bersicht hier alle einzeln aufgefhrt
Structure ASTELL                       ;aktuelle Stellung
  Feld.a[120]                          ;10*12 Felder
EndStructure 
Global *ASTELL.ASTELL = ?ASTELL        ;Zeiger auf das 10*12-Schachbrett

Structure WBSTELL                      ;aktuelle weisse Bauern-Stellung
  Pos.a[90]                            ;10*9 Felder, untere 2 Rand-Reihen und Grundlinie nicht
EndStructure 
Global *WBSTELL.WBSTELL = ?WBSTELL

Structure SBSTELL                      ;aktuelle schwarze Bauern-Stellung
  Pos.a[100]                           ;10*10 Felder, untere 2 Rand-Reihen nicht
EndStructure 
Global *SBSTELL.SBSTELL = ?SBSTELL

Structure KRICHT                       ;Zugmglichkeiten des Knigs
  ZugGen.l[8]                          ;8 Richtungen (ohne Rochade)
EndStructure 
Global *KRICHT.KRICHT = ?KRICHT        ;Zeiger auf die Richtungstabelle

Structure SRICHT                       ;Zugmglichkeiten des Springers
  ZugGen.l[8]                          ;8 Richtungen
EndStructure 
Global *SRICHT.SRICHT = ?SRICHT        ;Zeiger auf die Richtungstabelle

Structure LRICHT                       ;Zugmglichkeiten des Lufers/Dame
  ZugGen.l[4]                          ;4 Richtungen
EndStructure 
Global *LRICHT.LRICHT = ?LRICHT        ;Zeiger auf die Richtungstabelle

Structure TRICHT                       ;Zugmglichkeiten des Turms/Dame
  ZugGen.l[4]                          ;4 Richtungen
EndStructure 
Global *TRICHT.TRICHT = ?TRICHT        ;Zeiger auf die Richtungstabelle

Structure FIGWERT                      ;Figurenwerte
  Mat.l[6]
EndStructure 
Global *FIGWERT.FIGWERT = ?FIGWERT     ;Zeiger auf die Figurenwerte

Structure WBAUER                      ;weisse Felder-Bauerwerte
  Pos.l[90]
EndStructure 
Global *WBAUER.WBAUER = ?WBAUER        ;Zeiger auf die Werte

Structure SBAUER                       ;schwarze Felder-Bauerwerte
  Pos.l[90]
EndStructure 
Global *SBAUER.SBAUER = ?SBAUER        ;Zeiger auf die Werte

Structure ENTWICKLUNG                  ;Felder-Werte fr Figuren
  Pos.l[100]
EndStructure 
Global *ENTWICKLUNG.ENTWICKLUNG = ?ENTWICKLUNG   ;Zeiger auf die Werte

Structure ANZFIGW                      ;Anzahl der weissen Figuren fr jeden Halbzug
  Mat.l[32]                            ;fr 32 Halbzge
EndStructure 
Global *ANZFIGW.ANZFIGW = ANZFIGW.ANZFIGW
*ANZFIGW\Mat[0]=16                     ;in Grundstellung 16 weisse Figuren 

Structure ANZFIGS                      ;Anzahl der schwarzen Figuren fr jeden Halbzug
  Mat.l[32]                            ;fr 32 Halbzge
EndStructure 
Global *ANZFIGS.ANZFIGS = ANZFIGS.ANZFIGS
*ANZFIGS\Mat[0]=16                     ;in Grundstellung 16 schwarze Figuren 

Structure VARTIEFE                     ;variable Tiefe, Nominal-Tiefe plus Erweiterungen
  Prog.l[32]                           ;fr 32 Halbzge
EndStructure 
Global *VARTIEFE.VARTIEFE = VARTIEFE.VARTIEFE

Structure ALPHA                        ;untere Bewertungs-Schranke
  Prog.l[32]                           ;fr 32 Halbzge
EndStructure 
Global *ALPHA.ALPHA = ALPHA.ALPHA

Structure BETA                         ;obere Bewertungs-Schranke
  Prog.l[32]                           ;fr 32 Halbzge
EndStructure 
Global *BETA.BETA = BETA.BETA

Structure Z                            ;Zeiger in ZugTab
  ZugGen.l[32]                         ;fr 32 Halbzge
EndStructure 
Global *Z.Z = Z.Z

Structure AFELD                        ;fr die jeweilige Tiefe das letzte Ausgangsfeld
  Prog.l[32]                           ;fr 32 Halbzge
EndStructure 
Global *AFELD.AFELD = AFELD.AFELD

Structure ZFELD                        ;fr die jeweilige Tiefe das letzte Zielfeld
  Prog.l[32]                           ;fr 32 Halbzge
EndStructure 
Global *ZFELD.ZFELD = ZFELD.ZFELD

Structure AFELDH                       ;fr die jeweilige Tiefe der Inhalt des letzten Ausgangsfeldes
  Prog.l[32]                           ;fr 32 Halbzge
EndStructure 
Global *AFELDH.AFELDH = AFELDH.AFELDH

Structure ZFELDH                       ;fr die jeweilige Tiefe der Inhalt des letzten Zielfeldes
  Prog.l[32]                           ;fr 32 Halbzge
EndStructure 
Global *ZFELDH.ZFELDH = ZFELDH.ZFELDH

Structure ERWEITERUNG                  ;fr die jeweilige Tiefe die Rechentiefe-Erweiterung
  Prog.l[32]                           ;fr 32 Halbzge
EndStructure 
Global *ERWEITERUNG.ERWEITERUNG = ERWEITERUNG.ERWEITERUNG

Structure ANZBAUERW                    ;fr die jeweilige Tiefe die Anzahl der weissen Bauern
  Mat.l[32]                            ;fr 32 Halbzge
EndStructure 
Global *ANZBAUERW.ANZBAUERW = ANZBAUERW.ANZBAUERW
*ANZBAUERW\Mat[0]=8                    ;in Grundstellung 8 weisse Bauern

Structure ANZBAUERS                    ;fr die jeweilige Tiefe die Anzahl der schwarzen Bauern
  Mat.l[32]                            ;fr 32 Halbzge
EndStructure 
Global *ANZBAUERS.ANZBAUERS = ANZBAUERS.ANZBAUERS
*ANZBAUERS\Mat[0]=8                    ;in Grundstellung 8 schwarze Bauern

Structure MATW                         ;fr die jeweilige Tiefe die Materialsumme der weissen Figuren
  Mat.l[32]                            ;fr 32 Halbzge
EndStructure 
Global *MATW.MATW = MATW.MATW 
*MATW\Mat[0]=4077                      ;in Grundstellung alle weissen 16 Figuren, Knig ohne Wert

Structure MATS                         ;fr die jeweilige Tiefe die Materialsumme der schwarzen Figuren
  Mat.l[32]                            ;fr 32 Halbzge
EndStructure 
Global *MATS.MATS = MATS.MATS
*MATS\Mat[0]=4077                      ;in Grundstellung alle schwarzen 16 Figuren, Knig ohne Wert

Structure SCHACH                       ;ob Schachgebot, fr Erweiterungen
  Prog.l[32]                           ;fr 32 Halbzge
EndStructure 
Global *SCHACH.SCHACH = SCHACH.SCHACH

Structure TIEFENWERT                   ;End-Bewertungswert der jeweiligen Tiefe von BWS
  Prog.l[32]                           ;fr 32 Halbzge
EndStructure 
Global *TIEFENWERT.TIEFENWERT = TIEFENWERT.TIEFENWERT

Structure BESTERWERT                   ;aktueller Bewertungswert der jeweiligen Tiefe von BWS
  Prog.l[32]                           ;fr 32 Halbzge
EndStructure 
Global *BESTERWERT.BESTERWERT = BESTERWERT.BESTERWERT

Structure WBLINIE                      ;Anzahl weisser Bauer auf einer Linie
  Pos.c[9]                             ;fr 8 Linien (A bis H) und linkes Randfeld
EndStructure 
Global *WBLINIE.WBLINIE = WBLINIE.WBLINIE
For i=1 To 8
  *WBLINIE\Pos[i]=1
Next 

Structure SBLINIE                      ;Anzahl schwarzer Bauer auf einer Linie
  Pos.c[9]                             ;fr 8 Linien (A bis H) und linkes Randfeld
EndStructure 
Global *SBLINIE.SBLINIE = SBLINIE.SBLINIE
For i=1 To 8
  *SBLINIE\Pos[i]=1
Next 

Structure WTLINIE                      ;Anzahl weisse Trme auf einer Linie
  Pos.c[9]                             ;fr 8 Linien (A bis H) und linkes Randfeld
EndStructure 
Global *WTLINIE.WTLINIE = WTLINIE.WTLINIE
*WTLINIE\Pos[1]=1 
*WTLINIE\Pos[8]=1 

Structure STLINIE                      ;Anzahl schwarze Trme auf einer Linie
  Pos.c[9]                             ;fr 8 Linien (A bis H) und linkes Randfeld
EndStructure 
Global *STLINIE.STLINIE = STLINIE.STLINIE
*STLINIE\Pos[1]=1 
*STLINIE\Pos[8]=1 

Structure KILLERZUG1A                  ;fr Zugreihenfolge der Zuggeneratoren
  ZugGen.c[32]
EndStructure 
Global *KILLERZUG1A.KILLERZUG1A = KILLERZUG1A.KILLERZUG1A 

Structure KILLERZUG1Z
  ZugGen.c[32]
EndStructure 
Global *KILLERZUG1Z.KILLERZUG1Z = KILLERZUG1Z.KILLERZUG1Z 

Structure KILLERZUG2A
  ZugGen.c[32]
EndStructure 
Global *KILLERZUG2A.KILLERZUG2A = KILLERZUG2A.KILLERZUG2A 

Structure KILLERZUG2Z
  ZugGen.c[32]
EndStructure 
Global *KILLERZUG2Z.KILLERZUG2Z = KILLERZUG2Z.KILLERZUG2Z 

Structure ZUGTAB                       ;Zugtabelle, gefllt von den Zuggeneratoren
  ZugGen.c[14400]                      ;fr 32*218 Zge + je 1*$FFFF Endmarkierung, aufgerundet
EndStructure 
Global *ZUGTAB.ZUGTAB = ZUGTAB.ZUGTAB  ;Zeiger auf ZugTab

;---------------------------- P R O Z E D U R E N -------------------------------------------------
Procedure AttackFeldW()                ;Test, ob Weiss auf das Zielfeld Einfluss hat
;ZFeldZ wird als zu prfendes Feld bergeben
Attack=0
;Test auf Dame (diagonal) und Lufer
For a1=0 To 3                          ;4 Richtungen 
  i1=ZFeldZ
  k1= *LRICHT\ZugGen[a1]
  For j1=0 To 6                        ;max. 7 Zugmglichkeiten pro Richtung
    i1+k1                              ;auf Diagonalen nach Dame und Lufer suchen
    ZB= *ASTELL\Feld[i1] & %10011111
    If ZB=$15 Or ZB=$13                ;weisse Dame oder Lufer?
      Attack=1                         ;ja
      Goto AttackWEnd                  ;erspart eine Menge weitere If-Abfragen
     ElseIf ZB>=8                      ;Randfeld oder andere weisse/schwarze Figur?
      Break                            ;ja, diese Richtung ist erledigt
    EndIf        
  Next 
Next 
;Test auf Dame (horizontal und vertikal) und Turm
For a1=0 To 3                          ;4 Richtungen 
  i1=ZFeldZ
  k1= *TRICHT\ZugGen[a1]
  For j1=0 To 6                        ;max. 7 Zugmglichkeiten pro Richtung
    i1+k1                               ;auf Geraden nach Dame und Lufer suchen
    ZB= *ASTELL\Feld[i1] & %10011111
    If ZB=$15 Or ZB=$14                ;weisse Dame oder Turm?
      Attack=1                         ;ja
      Goto AttackWEnd                  ;erspart eine Menge weitere If-Abfragen
     ElseIf ZB>=8                      ;Randfeld oder andere weisse/schwarze Figur?
      Break                            ;ja, diese Richtung ist erledigt
    EndIf        
  Next 
Next 
;Test auf Springer
i1=ZFeldZ
For j1=0 To 7                          ;8 Zugmglichkeiten
  k1=i1 + *SRICHT\ZugGen[j1] 
  ZB= *ASTELL\Feld[k1] & %00010111
  If ZB=$12                            ;weisser Springer?
    Attack=1                           ;ja
    Goto AttackWEnd                    ;erspart eine Menge weitere If-Abfragen
  EndIf 
Next 
;Test auf Bauern
ZB= *ASTELL\Feld[i1+9] & %00010111
If ZB=$11                              ;weisser Bauer?
  Attack=1                             ;ja
  Goto AttackWEnd                      ;erspart eine Menge weitere If-Abfragen
EndIf 
ZB= *ASTELL\Feld[i1+11] & %00010111
If ZB=$11                              ;weisser Bauer?
  Attack=1                             ;ja
  Goto AttackWEnd                      ;erspart eine Menge weitere If-Abfragen
EndIf 
;Test auf Knig
For j1=0 To 7                          ;8 Zugmglichkeiten
  k1=i1 + *KRICHT\ZugGen[j1] 
  ZB= *ASTELL\Feld[k1] & %00010111
  If ZB=$16                            ;weisser Knig?
    Attack=1                           ;ja
    Break 
  EndIf 
Next 

AttackWEnd:
EndProcedure 
;--------------------------------------------------------------------------------------------------
Procedure AttackFeldS()                ;Test, ob Schwarz auf das Zielfeld Einfluss hat
;ZFeldZ wird als zu prfendes Feld bergeben
Attack=0
;Test auf Dame (diagonal) und Lufer
For a1=0 To 3                          ;4 Richtungen
  i1=ZFeldZ
  k1= *LRICHT\ZugGen[a1]
  For j1=0 To 6                        ;max. 7 Zugmglichkeiten pro Richtung
    i1+k1                              ;auf Diagonalen nach Dame und Lufer suchen
    ZB= *ASTELL\Feld[i1] & %10011111
    If ZB=$85 Or ZB=$83                ;schwarze Dame oder Lufer?
      Attack=1                         ;ja
      Goto AttackSEnd                  ;erspart eine Menge weitere If-Abfragen
     ElseIf ZB>=8                      ;Randfeld oder andere weisse/schwarze Figur?
      Break                            ;ja, diese Richtung ist erledigt
    EndIf        
  Next 
Next 
;Test auf Dame (horizontal und vertikal) und Turm
For a1=0 To 3                          ;4 Richtungen
  i1=ZFeldZ
  k1= *TRICHT\ZugGen[a1]
  For j1=0 To 6                        ;max. 7 Zugmglichkeiten pro Richtung
    i1+k1                              ;auf Geraden nach Dame und Lufer suchen
    ZB= *ASTELL\Feld[i1] & %10011111
    If ZB=$85 Or ZB=$84                ;schwarze Dame oder Turm?
      Attack=1                         ;ja
      Goto AttackSEnd                  ;erspart eine Menge weitere If-Abfragen
     ElseIf ZB>=8                      ;Randfeld oder andere weisse/schwarze Figur?
      Break                            ;ja, diese Richtung ist erledigt
    EndIf        
  Next 
Next 
;Test auf Springer
i1=ZFeldZ
For j1=0 To 7                          ;8 Zugmglichkeiten
  k1=i1 + *SRICHT\ZugGen[j1] 
  ZB= *ASTELL\Feld[k1] & %10000111
  If ZB=$82                            ;schwarzer Springer?
    Attack=1                           ;ja
    Goto AttackSEnd                    ;erspart eine Menge weitere If-Abfragen
  EndIf 
Next 
;Test auf Bauern
ZB= *ASTELL\Feld[i1-9] & %10000111
If ZB=$81                              ;schwarzer Bauer?
  Attack=1                             ;ja
  Goto AttackSEnd                      ;erspart eine Menge weitere If-Abfragen
EndIf 
ZB= *ASTELL\Feld[i1-11] & %10000111
If ZB=$81                              ;schwarzer Bauer?
  Attack=1                             ;ja
  Goto AttackSEnd                      ;erspart eine Menge weitere If-Abfragen
EndIf 
;Test auf Knig
For j1=0 To 7                          ;8 Zugmglichkeiten
  k1=i1 + *KRICHT\ZugGen[j1] 
  ZB= *ASTELL\Feld[k1] & %10000111
  If ZB=$86                            ;schwarzer Knig?
    Attack=1                           ;ja
    Break 
  EndIf 
Next 

AttackSEnd:
EndProcedure 
;--------------------------------------------------------------------------------------------------
Procedure SchreibTab()                 ;Zge von ZugGenW/S in Zugtabelle schreiben
;die generierten Zge werden fr jeden Halbzug gespeichert mit konstantem Abstand.
;Abstand jeweils 2*218 + 1*$FFFF = 438 Bytes. Die 218 rhren von den max.mglichen Zgen in einer
;legalen Stellung her und $FFFF kennzeichnen das Ende der Zge fr den Halbzug.
    ZZG+1
*ZUGTAB\ZugGen[ZZ]=AFeldZ
ZZ+1
*ZUGTAB\ZugGen[ZZ]=ZFeldZ
ZZ+1
EndProcedure 
;--------------------------------------------------------------------------------------------------
Procedure ZugGenW()                    ;weisse Zge generieren
;liefert die Pseudo-Liste der mglichen weissen Zge. Pseudo, weil ohne Test auf Knigs-Bedrohung
ZZ=AZ                                  ;Zeiger in die Zugtabelle

If *VARTIEFE\Prog[Tiefe] >= 0
  RuSu=0
 Else
  RuSu=1 
EndIf 

;Figuren (wenn vorhanden) bis auf den Knig
XL=*ANZFIGW\Mat[Tiefe]                 ;wieviel weisse Figuren sind berhaupt noch da? 
XL-1                                   ;Knig weg
D=0                                    ;Merker fr Dame. Nur, um Code-Zeilen einzusparen
*Z\ZugGen[Tiefe]=0                     ;Zeiger auf Anfang der Zugtabelle setzen

For i=98 To 21 Step -1                 ;von Feld H1 bis A8
  If XL>0                              ;wenn noch weisse Figur da ist
    AFeldZ=i                           ;Ausgangsfeld fr Zugtabelle
    XB = *ASTELL\Feld[i] & %00010111   ;ASTELL abklappern und Test ob weisse Figur
    If D=1                             ;letzte Figur war Dame, als Lufer schon abgehandelt
      D=0
      XB=$17                           ;wird so noch als Turm behandelt
    EndIf  

    If XB>$10                          ;ist dann weisse Figur
      If XB=$11                        ;weisser Bauer? 
        XL-1                           ;ja, eine weisse Figur weniger suchen
        ;"normale" Zge
        ZFeldZ=i-10                    ;1 Feld vorwrts
        YB= *ASTELL\Feld[ZFeldZ] & %00000111     ;Test, ob irgendeine Figur auf Feld steht
        If YB=0 And (RuSu=0 Or ZFeldZ<=28)  ;Feld frei? Und dann nur, wenn keine Ruhesuche oder ist Bauernumwandlung
          SchreibTab()                 ;ja, in Zugtabelle schreiben
          ;dann knnen wir auch auf 2 Felder vorwrts testen
          If i>=81                     ;Bauer noch auf 2.Reihe?
            ZFeldZ=i-20                ;2 Felder vorwrts
            YB= *ASTELL\Feld[ZFeldZ] & %00000111
            If YB=0 And RuSu=0        ;Feld frei und keine Ruhesuche?
              SchreibTab()             ;ja, in Zugtabelle schreiben
            EndIf 
          EndIf 
        EndIf 
        ;Schlagzug nach rechts
        ZFeldZ=i-9                     ;schlagen nach rechts
        YB= *ASTELL\Feld[ZFeldZ] & %10000000     ;Test, ob schwarze Figur auf Feld steht
        If YB
          SchreibTab()                 ;ja, in Zugtabelle schreiben (Schlagzug)       
        EndIf 
        ;Schlagzug nach links        
        ZFeldZ=i-11                    ;schlagen nach links
        YB= *ASTELL\Feld[ZFeldZ] & %10000000     ;Test, ob schwarze Figur auf Feld steht
        If YB
          SchreibTab()                 ;ja, in Zugtabelle schreiben (Schlagzug)       
        EndIf         
        ;en passant rechts
        If i+1 = SLastZugZ             ;letzter Gegnerzug Zielfeld rechts neben Bauern?
          YB= *ASTELL\Feld[SLastZugZ] & %00000111
          If YB=1                      ;Bauer?
            YB=SLastZugZ - SLastZugA
            If YB=20                   ;also Doppelschritt des schwarzen Bauern
              ZFeldZ=i-9
              SchreibTab()             ;e.p.-Zug in Tabelle (Schlagzug)
            EndIf
          EndIf 
        EndIf 
        ;en passant links
        If i-1 = SLastZugZ             ;letzter Gegnerzug Zielfeld links neben Bauern?
          YB= *ASTELL\Feld[SLastZugZ] & %00000111
          If YB=1                      ;Bauer?
            YB=SLastZugZ - SLastZugA
            If YB=20                   ;also Doppelschritt des schwarzen Bauern
              ZFeldZ=i-11
              SchreibTab()             ;e.p.-Zug in Tabelle (Schlagzug)
            EndIf
          EndIf 
        EndIf   
   
      ElseIf XB=$12                    ;weisser Springer?      
        XL-1
        For j=0 To 7                   ;8 Zugmglichkeiten
          ZFeldZ=i + *SRICHT\ZugGen[j]
          YB= *ASTELL\Feld[ZFeldZ] & %10011000
          If YB=0 And RuSu=0           ;Randfeld oder weisse/schwarze Figur?
            SchreibTab()               ;nein, in Zugtabelle schreiben
           ElseIf YB=$80
            SchreibTab()               ;Schlagzug
          EndIf 
        Next 
    
      ElseIf XB=$13 Or XB=$15          ;weisser Lufer oder Dame? 
        ;Dame (diagonal) und Lufer
        For a=0 To 3                   ;4 Richtungen
          k= *LRICHT\ZugGen[a]
          ZFeldZ=i
          For j=0 To 6                 ;max. 7 Zugmglichkeiten pro Richtung
            ZFeldZ+k
            YB= *ASTELL\Feld[ZFeldZ] & %10011000
            If YB=0 And RuSu=0         ;Randfeld oder weisse oder schwarze Figur?
              SchreibTab()             ;nein, in Zugtabelle schreiben
             ElseIf YB=$80             ;schwarze Figur?
              SchreibTab()             ;ja (Schlagzug)
              Break                    ;diese Richtung ist erledigt
             ElseIf YB=$10 Or YB=$8    ;weisse Figur oder Randfeld?
              Break                    ;ja, diese Richtung ist erledigt
            EndIf        
          Next 
        Next 
 
        If XB=$13
          XL-1                         ;fr Dame hier nicht, soll noch als "Turm" da sein
         Else
          XB=$17                       ;Merker fr Turm-Bewertung
          i+1                          ;also selbes Feld nochmal
          D=1                          ;Merker
        EndIf 
     
      ElseIf XB=$14 Or XB=$17          ;weisser Turm oder Dame (hier als Merker)? 
        XL-1
        ;Dame (horizontal und vertikal) und Turm
        For a=0 To 3                   ;4 Richtungen
          k= *TRICHT\ZugGen[a]
          ZFeldZ=i
          For j=0 To 6                 ;max. 7 Zugmglichkeiten pro Richtung
            ZFeldZ+k
            YB= *ASTELL\Feld[ZFeldZ] & %10011000
            If YB=0 And RuSu=0         ;Randfeld oder weisse oder schwarze Figur?
              SchreibTab()             ;nein, in Zugtabelle schreiben
             ElseIf YB=$80             ;schwarze Figur?
              SchreibTab()             ;ja (Schlagzug)
              Break                    ;diese Richtung ist erledigt
             ElseIf YB=$10 Or YB=$8    ;weisse Figur oder Randfeld?
              Break                    ;ja, diese Richtung ist erledigt
            EndIf        
          Next 
        Next 
      
      EndIf 
    EndIf 
   Else 
    Break                              ;keine weissen Figuren mehr da
  EndIf 

Next

;weisser Knig, dessen Position wird in WKFeld gespeichert und steht sofort zur Verfgung
AFeldZ=WKFeld                          ;Ausgangsfeld fr Zugtabelle 

For j=0 To 7                           ;8 Zugmglichkeiten (ohne Rochaden)
  ZFeldZ=WKFeld+*KRICHT\ZugGen[j]
  YB= *ASTELL\Feld[ZFeldZ] & %00011000
  If YB=0 And RuSu=0                   ;Randfeld oder weisse Figur?
    SchreibTab()                       ;nein, in Zugtabelle schreiben
  EndIf 
Next 

;Rochaden
XB= *ASTELL\Feld[WKFeld] & %00100000   ;Test ob Knig schon gezogen

If XB=0
  ZFeldZ=95
  AttackFeldS()                        ;Test, ob E1 von Schwarz bedroht wird, also Weiss
EndIf                                  ; im Schach steht

If XB=0 And Attack=0 And RuSu=0
  If *ASTELL\Feld[98] = $14            ;Test ob unbewegter Turm auf H1 steht            
    If (*ASTELL\Feld[96] & %10010000) = 0   ;Feld F1 leer?
      If (*ASTELL\Feld[97] & %10010000) = 0 ;Feld G1 leer?
        ZFeldZ=96
        AttackFeldS()                  ;Test, ob F1 von Schwarz bedroht wird
        If Attack=0
          ZFeldZ=97
          AttackFeldS()                ;Test, ob G1 von Schwarz bedroht wird
          If Attack=0   
            AFeldZ=95 : ZFeldZ=97
            SchreibTab()               ;kleine Rochade als E1-G1 in Zugtabelle schreiben
          EndIf 
        EndIf 
      EndIf
    EndIf
  EndIf  
 
  If *ASTELL\Feld[91] = $54            ;Test ob unbewegter Turm auf A1 steht
    If (*ASTELL\Feld[94] & %10010000) = 0   ;Feld D1 leer?
      If (*ASTELL\Feld[93] & %10010000) = 0 ;Feld C1 leer?
        If (*ASTELL\Feld[92] & %10010000) = 0    ;Feld B1 leer?    
          ZFeldZ=94
          AttackFeldS()                ;Test, ob D1 von Schwarz bedroht wird
          If Attack=0
            ZFeldZ=93
            AttackFeldS()              ;Test, ob C1 von Schwarz bedroht wird
            If Attack=0   
              AFeldZ=95 : ZFeldZ=93
              SchreibTab()             ;grosse Rochade als E1-C1 in Zugtabelle schreiben
            EndIf 
          EndIf 
        EndIf
      EndIf
    EndIf
  EndIf 
EndIf 

AFeldZ=$FF : ZFeldZ=$FF                ;das Ende der Zge auf dieser Halbzug-Ebene markieren
SchreibTab()

;testen, ob bei den generierten Zgen "Killerzge" dabei sind, wenn ja, diese nach vorn setzen
XB=0
For i=AZ To ZZ-2 Step 2
  If *ZUGTAB\ZugGen[i]=*KILLERZUG1A\ZugGen[Tiefe]
    If *ZUGTAB\ZugGen[i+1]=*KILLERZUG1Z\ZugGen[Tiefe]
      Swap *ZUGTAB\ZugGen[i], *ZUGTAB\ZugGen[AZ]
      Swap *ZUGTAB\ZugGen[i+1], *ZUGTAB\ZugGen[AZ+1]
      XB+1
    EndIf 
  EndIf
  If *ZUGTAB\ZugGen[i]=*KILLERZUG2A\ZugGen[Tiefe]
    If *ZUGTAB\ZugGen[i+1]=*KILLERZUG2Z\ZugGen[Tiefe]
      Swap *ZUGTAB\ZugGen[i], *ZUGTAB\ZugGen[AZ]
      Swap *ZUGTAB\ZugGen[i+1], *ZUGTAB\ZugGen[AZ+1]
      XB+1
    EndIf 
  EndIf
  If XB=2
    Break
  EndIf 
Next

EndProcedure 
;--------------------------------------------------------------------------------------------------
Procedure ZugGenS()                    ;schwarze Zge generieren
;liefert die Pseudo-Liste der mglichen schwarzen Zge. Pseudo, weil ohne Test auf Knigs-Bedrohung
ZZ=AZ                                  ;Zeiger in die Zugtabelle

If *VARTIEFE\Prog[Tiefe] >= 0
  RuSu=0
 Else
  RuSu=1 
EndIf 

;Figuren (wenn vorhanden) bis auf den Knig
XL=*ANZFIGS\Mat[Tiefe]                 ;wieviel schwarze Figuren sind berhaupt noch da? 
XL-1                                   ;Knig weg
D=0                                    ;Merker fr Dame. Nur, um Code-Zeilen einzusparen
*Z\ZugGen[Tiefe]=0                     ;Zeiger auf Anfang der Zugtabelle setzen

For i=21 To 98                         ;von Feld A8 bis H1
  If XL>0                              ;wenn noch schwarze Figur da ist
    AFeldZ=i                           ;Ausgangsfeld fr Zugtabelle
    XB = *ASTELL\Feld[i] & %10000111   ;ASTELL abklappern und Test ob schwarze Figur
    If D=1                             ;letzte Figur war Dame, als Lufer schon abgehandelt
      D=0
      XB=$87                           ;wird so noch als Turm behandelt (Merker)
    EndIf  

    If XB>$80                          ;ist dann schwarze Figur
      If XB=$81                        ;schwarzer Bauer? 
        XL-1                           ;ja, eine schwarze Figur weniger suchen
        ;"normale" Zge
        ZFeldZ=i+10                    ;1 Feld vorwrts
        YB= *ASTELL\Feld[ZFeldZ] & %00000111     ;Test, ob irgendeine Figur auf Feld steht
        If YB=0 And (RuSu=0 Or ZFeldZ>=91)  ;Feld frei? Und dann nur, wenn keine Ruhesuche oder ist Bauernumwandlung
          SchreibTab()                 ;ja, in Zugtabelle schreiben
          ;dann knnen wir auch auf 2 Felder vorwrts testen
          If i<=38                     ;Bauer noch auf 7.Reihe?  
            ZFeldZ=i+20                ;2 Felder vorwrts
            YB= *ASTELL\Feld[ZFeldZ] & %00000111
            If YB=0 And RuSu=0         ;Feld frei und keine Ruhesuche?
              SchreibTab()             ;ja, in Zugtabelle schreiben
            EndIf 
          EndIf
        EndIf 
        ;Schlagzug nach rechts
        ZFeldZ=i+11                    ;schlagen nach rechts
        YB= *ASTELL\Feld[ZFeldZ] & %00010000                 ;Test, ob weisse Figur auf Feld steht
        If YB
          SchreibTab()                 ;ja, in Zugtabelle schreiben (Schlagzug)        
        EndIf 
        ;Schlagzug nach links        
        ZFeldZ=i+9                     ;schlagen nach links
        YB= *ASTELL\Feld[ZFeldZ] & %00010000     ;Test, ob weisse Figur auf Feld steht
        If YB
          SchreibTab()                 ;ja, in Zugtabelle schreiben (Schlagzug)       
        EndIf         
        ;en passant rechts
        If i+1 = WLastZugZ             ;letzter Gegnerzug Zielfeld rechts neben Bauern?
          YB= *ASTELL\Feld[WLastZugZ] & %00000111
          If YB=1                      ;Bauer?
            YB=WLastZugA - WLastZugZ
            If YB=20                   ;also Doppelschritt des weissen Bauern
              ZFeldZ=i+11
              SchreibTab()             ;e.p.-Zug in Tabelle (Schlagzug)
            EndIf
          EndIf 
        EndIf 
        ;en passant links
        If i-1 = WLastZugZ             ;letzter Gegnerzug Zielfeld links neben Bauern?
          YB= *ASTELL\Feld[WLastZugZ] & %00000111
          If YB=1                      ;Bauer?
            YB=WLastZugA - WLastZugZ
            If YB=20                   ;also Doppelschritt des weissen Bauern
              ZFeldZ=i+9
              SchreibTab()             ;e.p.-Zug in Tabelle (Schlagzug)
            EndIf
          EndIf 
        EndIf   
   
      ElseIf XB=$82                    ;schwarzer Springer?      
        XL-1
        For j=0 To 7                   ;8 Zugmglichkeiten
          ZFeldZ=i + *SRICHT\ZugGen[j]
          YB= *ASTELL\Feld[ZFeldZ] & %10011000
          If YB=0 And RuSu=0           ;Randfeld oder weisse/schwarze Figur?
            SchreibTab()               ;nein, in Zugtabelle schreiben
           ElseIf YB=$10
            SchreibTab()               ;Schlagzug
          EndIf 
        Next 
  
      ElseIf XB=$83 Or XB=$85          ;schwarzer Lufer oder Dame? 
        ;Dame (diagonal) und Lufer
        For a=0 To 3                   ;4 Richtungen
          k= *LRICHT\ZugGen[a]
          ZFeldZ=i
          For j=0 To 6                 ;max. 7 Zugmglichkeiten pro Richtung
            ZFeldZ+k
            YB= *ASTELL\Feld[ZFeldZ] & %10011000
            If YB=0 And RuSu=0         ;Randfeld oder weisse oder schwarze Figur?
              SchreibTab()             ;nein, in Zugtabelle schreiben
             ElseIf YB=$10             ;weisse Figur?
              SchreibTab()             ;ja (Schlagzug)
              Break                    ;diese Richtung ist erledigt
             ElseIf YB=$80 Or YB=$8    ;schwarze Figur oder Randfeld?
              Break                    ;ja, diese Richtung ist erledigt
            EndIf        
          Next 
        Next        
 
        If XB=$83
          XL-1                         ;fr Dame hier nicht, soll noch als "Turm" da sein
         Else
          XB=$87                       ;Merker fr Turm-Bewertung
          i-1                          ;also selbes Feld nochmal
          D=1                          ;Merker
        EndIf 
      
      ElseIf XB=$84 Or XB=$87          ;schwarzer Turm oder Dame (Merker)? 
        XL-1
        ;Dame (horizontal und vertikal) und Turm
        For a=0 To 3                   ;4 Richtungen
          k= *TRICHT\ZugGen[a]
          ZFeldZ=i
          For j=0 To 6                 ;max. 7 Zugmglichkeiten pro Richtung
            ZFeldZ+k
            YB= *ASTELL\Feld[ZFeldZ] & %10011000
            If YB=0 And RuSu=0         ;Randfeld oder weisse oder schwarze Figur?
              SchreibTab()             ;nein, in Zugtabelle schreiben
             ElseIf YB=$10             ;weisse Figur?
              SchreibTab()             ;ja (Schlagzug)
              Break                    ;diese Richtung ist erledigt
             ElseIf YB=$80 Or YB=$8    ;schwarze Figur oder Randfeld?
              Break                    ;ja, diese Richtung ist erledigt
            EndIf        
          Next 
        Next       
      
      EndIf 
    EndIf 
   Else 
    Break                              ;keine weissen Figuren mehr da
  EndIf 

Next

;schwarzer Knig, dessen Position wird in SKFeld gespeichert und steht sofort zur Verfgung
AFeldZ=SKFeld                          ;Ausgangsfeld fr Zugtabelle 

For j=0 To 7                           ;8 Zugmglichkeiten (ohne Rochaden)
  ZFeldZ=SKFeld+*KRICHT\ZugGen[j]
  YB= *ASTELL\Feld[ZFeldZ] & %10001000
  If YB=0 And RuSu=0                   ;Randfeld oder schwarze Figur?
    SchreibTab()                       ;nein, in Zugtabelle schreiben
  EndIf 
Next 

;Rochaden
XB= *ASTELL\Feld[SKFeld] & %00100000   ;Test ob Knig schon gezogen
If XB=0
  ZFeldZ=25
  AttackFeldW()                        ;Test, ob E8 von Weiss bedroht wird, also Schwarz
EndIf                                  ; im Schach steht

If XB=0 And Attack=0 And RuSu=0
  If *ASTELL\Feld[28] = $C4            ;Test ob unbewegter Turm auf H8 steht          
    If (*ASTELL\Feld[26] & %10010000) = 0   ;Feld F8 leer?
      If (*ASTELL\Feld[27] & %10010000) = 0 ;Feld G8 leer?
        ZFeldZ=26
        AttackFeldW()                  ;Test, ob F8 von Weiss bedroht wird
        If Attack=0
          ZFeldZ=27
          AttackFeldW()                ;Test, ob G8 von Weiss bedroht wird
          If Attack=0   
            AFeldZ=25 : ZFeldZ=27
            SchreibTab()               ;kleine Rochade als E8-G8 in Zugtabelle schreiben
          EndIf 
        EndIf 
      EndIf
    EndIf
  EndIf  
 
  If *ASTELL\Feld[21] = $84            ;Test ob unbewegter Turm auf A8 steht
    If (*ASTELL\Feld[24] & %10010000) = 0   ;Feld D8 leer?
      If (*ASTELL\Feld[23] & %10010000) = 0 ;Feld C8 leer?
        If (*ASTELL\Feld[22] & %10010000) = 0    ;Feld B8 leer?       
          ZFeldZ=24
          AttackFeldW()                ;Test, ob D8 von Weiss bedroht wird
          If Attack=0
            ZFeldZ=23
            AttackFeldW()              ;Test, ob C8 von Weiss bedroht wird
            If Attack=0   
              AFeldZ=25 : ZFeldZ=23
              SchreibTab()             ;grosse Rochade als E8-C8 in Zugtabelle schreiben
            EndIf 
          EndIf 
        EndIf
      EndIf
    EndIf
  EndIf 
EndIf 

AFeldZ=$FF : ZFeldZ=$FF                ;das Ende der Zge auf dieser Halbzug-Ebene markieren
SchreibTab()

;testen, ob bei den generierten Zgen "Killerzge" dabei sind, wenn ja, diese nach vorn setzen
XB=0
For i=AZ To ZZ-2 Step 2
  If *ZUGTAB\ZugGen[i]=*KILLERZUG1A\ZugGen[Tiefe]
    If *ZUGTAB\ZugGen[i+1]=*KILLERZUG1Z\ZugGen[Tiefe]
      Swap *ZUGTAB\ZugGen[i], *ZUGTAB\ZugGen[AZ]
      Swap *ZUGTAB\ZugGen[i+1], *ZUGTAB\ZugGen[AZ+1]
      XB+1
    EndIf 
  EndIf
  If *ZUGTAB\ZugGen[i]=*KILLERZUG2A\ZugGen[Tiefe]
    If *ZUGTAB\ZugGen[i+1]=*KILLERZUG2Z\ZugGen[Tiefe]
      Swap *ZUGTAB\ZugGen[i], *ZUGTAB\ZugGen[AZ]
      Swap *ZUGTAB\ZugGen[i+1], *ZUGTAB\ZugGen[AZ+1]
      XB+1
    EndIf 
  EndIf
  If XB=2
    Break
  EndIf 
Next

EndProcedure 
;--------------------------------------------------------------------------------------------------
Procedure BrettMal()                   ;- Brett zeichnen
k=0 : x=0 : y=0                        ;k=Hilfsvariable fr Feldfarbe
For i=21 To 98                         ;von A8 nach H1
  XB=*ASTELL\Feld[i]                   ;ASTELL auslesen
  If XB<>8                             ;Test auf Randfeld
    j=i+k
    YB=j & 1     
    ZB=XB & %10010111  
    If YB=1                            ;dunkles Feld
      ElseIf ZB=0   : F=LD  : ElseIf ZB=$11 : F=WBD : ElseIf ZB=$12 : F=WSD    
      ElseIf ZB=$13 : F=WLD : ElseIf ZB=$14 : F=WTD : ElseIf ZB=$15 : F=WDD
      ElseIf ZB=$16 : F=WKD : ElseIf ZB=$81 : F=SBD : ElseIf ZB=$82 : F=SSD    
      ElseIf ZB=$83 : F=SLD : ElseIf ZB=$84 : F=STS : ElseIf ZB=$85 : F=SDD
      ElseIf ZB=$86 : F=SKD  
    EndIf  
      
    If YB=0                            ;helles Feld
      ElseIf ZB=0   : F=LH  : ElseIf ZB=$11 : F=WBH : ElseIf ZB=$12 : F=WSH    
      ElseIf ZB=$13 : F=WLH : ElseIf ZB=$14 : F=WTH : ElseIf ZB=$15 : F=WDH
      ElseIf ZB=$16 : F=WKH : ElseIf ZB=$81 : F=SBH : ElseIf ZB=$82 : F=SSH   
      ElseIf ZB=$83 : F=SLH : ElseIf ZB=$84 : F=STH : ElseIf ZB=$85 : F=SDH
      ElseIf ZB=$86 : F=SKH    
    EndIf 
  
    ImageGadget(i, 15+x, 10+y, 38, 38, F)

    x+38
    If x>281
      k+1 : x=0 : y+38
    EndIf
  EndIf 
Next 
EndProcedure
;--------------------------------------------------------------------------------------------------
Procedure AWZ()                        ;weissen Zug intern ausfhren
YL= *Z\ZugGen[Tiefe]                   ;aktuellen Zeiger in ZugTab auslesen 
YL+AZ 
XB=*ZUGTAB\ZugGen[YL]                  ;AFeld auslesen
If XB<>$FF                             ;nicht Ende Zugtabelle fr diese Tiefe 
  *Z\ZugGen[Tiefe]+2                   ;zeigt auf nchsten weissen Zug (AFeld) oder Ende ZugTab
  YB=*ZUGTAB\ZugGen[YL+1]              ;ZFeld auslesen
  Tiefe+1                              ;da noch Zug vorhanden jetzt nchste Rechentiefe
  *AFELD\Prog[Tiefe]=XB                ;AFeld und ZFeld sichern
  *ZFELD\Prog[Tiefe]=YB
  WLASTZUGA=XB                         ;fr schnelleren Zugriff
  WLASTZUGZ=YB

  XB= *ASTELL\Feld[WLASTZUGA]          ;Inhalt von AFeld und ZFeld sichern zur schnellen
  *AFELDH\Prog[Tiefe]=XB               ; Wiederherstellung
  YB= *ASTELL\Feld[WLASTZUGZ]
  *ZFELDH\Prog[Tiefe]=YB

  *ASTELL\Feld[WLASTZUGA]=0            ;AFeld leeren
  XB & $17                             ;von Inhalt AFeld nur Figur, XB wird unten nochmal bentigt
  *ASTELL\Feld[WLASTZUGZ]=XB           ;ZFeld mit Figur von AFeld fllen  
  *ASTELL\Feld[WLASTZUGZ] | $20        ;Bit fr Figur schon mal gezogen setzen (OR)
  ;jetzt div.Werte von Tiefe-1 "hochholen"
  *ERWEITERUNG\Prog[Tiefe] = *ERWEITERUNG\Prog[Tiefe-1]
  *ANZFIGW\Mat[Tiefe] = *ANZFIGW\Mat[Tiefe-1]
  *ANZFIGS\Mat[Tiefe] = *ANZFIGS\Mat[Tiefe-1]
  *ANZBAUERW\Mat[Tiefe] = *ANZBAUERW\Mat[Tiefe-1]
  *ANZBAUERS\Mat[Tiefe] = *ANZBAUERS\Mat[Tiefe-1]
  *MATW\Mat[Tiefe] = *MATW\Mat[Tiefe-1]
  *MATS\Mat[Tiefe] = *MATS\Mat[Tiefe-1]

  YB & 7                               ;YB ist noch Inhalt ZFeld, auf Figur testen
  If YB                                ;auf Zielfeld stand eine schwarze Figur 
    *ANZFIGS\Mat[Tiefe]-1              ;eine schwarze Figur weg   
    *MATS\Mat[Tiefe] - *FIGWERT\Mat[YB]     ;deren Materialwert holen und von Gesamtwert subtrahieren
    If YB=1                            ;wurde ein schwarzer Bauer geschlagen?
      *ANZBAUERS\Mat[Tiefe]-1          ;war Bauer, also da auch einen weg
      *SBSTELL\Pos[WLASTZUGZ] ! $80    ;diesen Bauer in SBSTELL lschen (XOR!)
      *SBSTELL\Pos[WLASTZUGZ+9]-1      ; XOR $80 lsst die Einflussfelder unberhrt
      *SBSTELL\Pos[WLASTZUGZ+11]-1     ;die beiden Einflussfelder verringern 
      ZL=Val(Mid(Str(WLASTZUGZ),2,1))  ;liefert die Linie (1 bis 8) des geschlagenen Bauern
      *SBLINIE\Pos[ZL]-1               ;auf dieser Linie ein schwarzer Bauer weniger
     ElseIf YB=4                       ;wurde ein schwarzer Turm geschlagen?
      ZL=Val(Mid(Str(WLASTZUGZ),2,1))  ;liefert die Linie (1 bis 8) des geschlagenen Turms
      *STLINIE\Pos[ZL]-1               ;auf dieser Linie ein schwarzer Turm weniger
    EndIf
  EndIf

  ;jetzt die gezogene weisse Figur auf Bauern, Turm-und Knigszge untersuchen
  YL=Val(Mid(Str(WLASTZUGA),2,1))      ;liefert die Linie (1 bis 8) des Ausgangsfeldes
  ZL=Val(Mid(Str(WLASTZUGZ),2,1))      ;liefert die Linie (1 bis 8) des Zielfeldes  
  If XB=$11                            ;XB ist noch weisse Figur, Test auf Bauer
    *WBSTELL\Pos[WLASTZUGA] ! $10      ;diesen Bauer in WBSTELL lschen (XOR!)
    *WBSTELL\Pos[WLASTZUGA-9]-1        ; XOR $10 lsst die Einflussfelder unberhrt
    *WBSTELL\Pos[WLASTZUGA-11]-1       ;die beiden Einflussfelder verringern
    *WBLINIE\Pos[YL]-1                 ;auf Ausgangsfeld-Linie ein weisser Bauer weniger    
    ;hier Test auf Bauernumwandlung
    If WLASTZUGZ <= 28                 ;8.Reihe?
      *ANZBAUERW\Mat[Tiefe]-1          ;Bauer weg
      *ASTELL\Feld[WLASTZUGZ] = $15    ;weisse Dame setzen
      *MATW\Mat[Tiefe]+875             ;875=Dame-Bauer
     Else 
      ZB=WLASTZUGA-WLASTZUGZ           ;10 oder 20 wren "normale" Bauernschritte
      ;jetzt Test auf en passant    
      If YB=0 And (ZB=9 Or ZB=11)      ;war das Zielfeld leer und wurde trotzdem geschlagen?
        *ASTELL\Feld[WLASTZUGZ+10] & $40    ;den schwarzen e.p.-Bauern entfernen, nur Feldfarbe bleibt  
        *ANZFIGS\Mat[Tiefe]-1          ;eine schwarze Figur weg  
        *ANZBAUERS\Mat[Tiefe]-1        ;Bauer auch weg
        *MATS\Mat[Tiefe]-100           ;Material um Bauernwert (=100) reduzieren
        *SBSTELL\Pos[WLASTZUGZ+10] ! $80     ;diesen Bauer in SBSTELL lschen (XOR!)
        *SBSTELL\Pos[WLASTZUGZ+19]-1   ;die beiden Einflussfelder verringern 
        *SBSTELL\Pos[WLASTZUGZ+21]-1
        *SBLINIE\Pos[ZL]-1             ;auf dieser Linie ein schwarzer Bauer weniger
      EndIf 
      *WBLINIE\Pos[ZL]+1               ;auf Zielfeld-Linie ein weisser Bauer mehr
      *WBSTELL\Pos[WLASTZUGZ] ! $10    ;diesen Bauer in WBSTELL setzen (XOR!)       
      *WBSTELL\Pos[WLASTZUGZ-9]+1      ; XOR $10 lsst die Einflussfelder unberhrt
      *WBSTELL\Pos[WLASTZUGZ-11]+1     ;die beiden Einflussfelder erhhen
    EndIf 

   ElseIf XB=$14                       ;Turm?
    *WTLINIE\Pos[YL]-1                 ;von Linie Ausgangsfeld weg
    *WTLINIE\Pos[ZL]+1                 ;auf Linie Zielfeld hinzu  
   ElseIf XB=$16                       ;Knig? 
    WKFELD=WLASTZUGZ                   ;aktualisieren 
    WKLINIE=Val(Mid(Str(WLASTZUGZ),2,1))    ;liefert die Linie (1 bis 8) des Zielfeldes
    ZL=WLASTZUGZ-WLASTZUGA
    If ZL=2                            ;dann ist es kleine Rochade (-2 = grosse)
      RochStatusW=1
      *ASTELL\Feld[98]=0               ;Turm H1 lschen
      *WTLINIE\Pos[8]-1
      *ASTELL\Feld[96]=$14             ;Turm F1 hinzufgen
      *WTLINIE\Pos[6]+1     
     ElseIf ZL=-2                      ;grosse Rochade 
      RochStatusW=2
      *ASTELL\Feld[91]=0               ;Turm A1 lschen
      *WTLINIE\Pos[1]-1
      *ASTELL\Feld[94]=$14             ;Turm D1 hinzufgen
      *WTLINIE\Pos[4]+1     
    EndIf 
  EndIf 

AZ+438                                 ;neuer Zeiger in ZugTab
Color=128                              ;Schwarz jetzt am Zug
EndIf 
EndProcedure
;--------------------------------------------------------------------------------------------------
Procedure ZWZ()                        ;weissen Zug intern zurcknehmen
XB= *AFELD\Prog[Tiefe]                 ;AFeld und ZFeld zurckholen
YB= *ZFELD\Prog[Tiefe]

ZB= *ZFELDH\Prog[Tiefe]
*ASTELL\Feld[YB]=ZB                    ;Inhalt vom Zielfeld komplett zurck

YL=Val(Mid(Str(XB),2,1))               ;liefert die Linie (1 bis 8) des Ausgangsfeldes
ZL=Val(Mid(Str(YB),2,1))               ;liefert die Linie (1 bis 8) des Zielfeldes    
ZB & 7                                 ;Inhalt Zielfeld
WB=ZB                                  ;fr spteren Test auf e.p.
If ZB=1                                ;wurde schwarzer Bauer geschlagen?
  *SBSTELL\Pos[YB] ! $80               ;wieder setzen
  *SBSTELL\Pos[YB+9]+1                 ;die beiden Einflussfelder wieder erhhen 
  *SBSTELL\Pos[YB+11]+1
  *SBLINIE\Pos[ZL]+1                   ;auf dieser Linie ein schwarzer Bauer wieder mehr
 ElseIf ZB=4                           ;wurde schwarzer Turm geschlagen?
  *STLINIE\Pos[ZL]+1                   ;auf Linie Zielfeld wieder hinzu 
EndIf 

ZB= *AFELDH\Prog[Tiefe]
*ASTELL\Feld[XB]=ZB                    ;Inhalt vom Ausgangsfeld komplett zurck
ZB & 7                                 ;Figur auf Ausgangsfeld
If ZB=1                                ;eigener (weisser) Bauernzug?
  *WBSTELL\Pos[XB] ! $10               ;diesen Bauer in WBSTELL setzen (XOR!)       
  *WBSTELL\Pos[XB-9]+1                 ;die beiden Einflussfelder erhhen
  *WBSTELL\Pos[XB-11]+1
  If YB<=28                            ;Bauernumwandlung?
    *WBLINIE\Pos[YL]+1                 ;mehr nicht!
   ElseIf YB>28 
    *WBSTELL\Pos[YB] ! $10             ;Bauer in WBSTELL lschen (XOR!)
    *WBSTELL\Pos[YB-9]-1               ;die beiden Einflussfelder verringern
    *WBSTELL\Pos[YB-11]-1   
    If WB=0                            ;Zielfeld leer wegen Test auf e.p. ?
      VB=XB-YB                         ;Differenz AFeld-ZFeld
      If VB=9 Or VB=11                 ;dann war es e.p.
        *ASTELL\Feld[YB+10] | $81      ;den schwarzen e.p.-Bauern wieder rein
        *SBSTELL\Pos[YB+10] ! $80      ;wieder setzen
        *SBSTELL\Pos[YB+19]+1          ;die beiden Einflussfelder wieder erhhen 
        *SBSTELL\Pos[YB+21]+1
        *SBLINIE\Pos[ZL]+1             ;auf dieser Linie ein schwarzer Bauer wieder mehr     
        *WBLINIE\Pos[ZL]-1 
        *WBLINIE\Pos[YL]+1
      EndIf
     ElseIf WB<>0                      ;Zielfeld war nicht leer, also Schlagzug
      *WBLINIE\Pos[ZL]-1 
      *WBLINIE\Pos[YL]+1
    EndIf  
  EndIf 
 
 ElseIf ZB=4                           ;Turm?
  *WTLINIE\Pos[ZL]-1                   ;von Linie Zielfeld weg
  *WTLINIE\Pos[YL]+1                   ;auf Linie Ausgangsfeld hinzu  
 
 ElseIf ZB=6                           ;Knig?
  WKFeld=XB                            ;wieder Ausgangsfeld 
  WKLinie=YL
  VB=YB-XB                             ;Differenz ZFeld-AFeld
  If VB=2                              ;kleine Rochade
    RochStatusW=0
    *ASTELL\Feld[98]=$14               ;Turm H1 wieder rein
    *ASTELL\Feld[96]=0                 ;Turm F1 wieder weg 
    *WTLINIE\Pos[6]-1
    *WTLINIE\Pos[8]+1     
   ElseIf VB=254                       ;grosse Rochade
    RochStatusW=0
    *ASTELL\Feld[91]=$54               ;Turm A1 wieder rein
    *ASTELL\Feld[94]=0                 ;Turm D1 wieder weg 
    *WTLINIE\Pos[4]-1
    *WTLINIE\Pos[1]+1     
  EndIf 
EndIf 

Tiefe-1                                ;eine Rechentiefe wieder zurck
AZ-438                                 ;Zeiger in ZugTab wieder auf weisse Zge
Color=0                                ;Weiss wieder am Zug
EndProcedure
;--------------------------------------------------------------------------------------------------
Procedure ASZ()                        ;schwarzen Zug intern ausfhren
YL= *Z\ZugGen[Tiefe]                   ;aktuellen Zeiger in ZugTab auslesen 
YL+AZ 
XB=*ZUGTAB\ZugGen[YL]                  ;AFeld auslesen
If XB<>$FF                             ;nicht Ende Zugtabelle fr diese Tiefe 
  *Z\ZugGen[Tiefe]+2                   ;zeigt auf nchsten weissen Zug (AFeld) oder Ende ZugTab
  YB=*ZUGTAB\ZugGen[YL+1]              ;ZFeld auslesen
  Tiefe+1                              ;da noch Zug vorhanden jetzt nchste Rechentiefe
  *AFELD\Prog[Tiefe]=XB                ;AFeld und ZFeld sichern
  *ZFELD\Prog[Tiefe]=YB
  SLASTZUGA=XB                         ;fr schnelleren Zugriff
  SLASTZUGZ=YB

  XB= *ASTELL\Feld[SLASTZUGA]          ;Inhalt von AFeld und ZFeld sichern zur schnellen
  *AFELDH\Prog[Tiefe]=XB               ; Wiederherstellung
  YB= *ASTELL\Feld[SLASTZUGZ]
  *ZFELDH\Prog[Tiefe]=YB

  *ASTELL\Feld[SLASTZUGA]=0            ;AFeld leeren
  XB & $87                             ;von Inhalt AFeld nur Figur, XB wird unten nochmal bentigt
  *ASTELL\Feld[SLASTZUGZ]=XB           ;ZFeld mit Figur von AFeld fllen  
  *ASTELL\Feld[SLASTZUGZ] | $20        ;Bit fr Figur schonmal gezogen setzen (OR)
  ;jetzt div.Werte von Tiefe-1 "hochholen"
  *ERWEITERUNG\Prog[Tiefe] = *ERWEITERUNG\Prog[Tiefe-1]
  *ANZFIGS\Mat[Tiefe] = *ANZFIGS\Mat[Tiefe-1]
  *ANZFIGW\Mat[Tiefe] = *ANZFIGW\Mat[Tiefe-1]
  *ANZBAUERS\Mat[Tiefe] = *ANZBAUERS\Mat[Tiefe-1]
  *ANZBAUERW\Mat[Tiefe] = *ANZBAUERW\Mat[Tiefe-1]
  *MATS\Mat[Tiefe] = *MATS\Mat[Tiefe-1]
  *MATW\Mat[Tiefe] = *MATW\Mat[Tiefe-1]

  YB & 7                               ;YB ist noch Inhalt ZFeld, auf Figur testen
  If YB
    *ANZFIGW\Mat[Tiefe]-1              ;eine weisse Figur weg   
    *MATW\Mat[Tiefe] - *FIGWERT\Mat[YB]     ;deren Materialwert holen und von Gesamtwert subtrahieren
    If YB=1                            ;wurde ein weisser Bauer geschlagen?
      *ANZBAUERW\Mat[Tiefe]-1          ;war Bauer, also da auch einen weg
      *WBSTELL\Pos[SLASTZUGZ] ! $10    ;diesen Bauer in WBSTELL lschen (XOR!)
      *WBSTELL\Pos[SLASTZUGZ-9]-1      ; XOR $10 lsst die Einflussfelder unberhrt
      *WBSTELL\Pos[SLASTZUGZ-11]-1     ;die beiden Einflussfelder verringern 
      ZL=Val(Mid(Str(SLASTZUGZ),2,1))  ;liefert die Linie (1 bis 8) des geschlagenen Bauern
      *WBLINIE\Pos[ZL]-1               ;auf dieser Linie ein weisser Bauer weniger
     ElseIf YB=4                       ;wurde ein weisser Turm geschlagen?
      ZL=Val(Mid(Str(SLASTZUGZ),2,1))  ;liefert die Linie (1 bis 8) des geschlagenen Turms
      *WTLINIE\Pos[ZL]-1               ;auf dieser Linie ein weisser Turm weniger
    EndIf
  EndIf

  ;jetzt die gezogene schwarze Figur auf Bauern, Turm-und Knigszge untersuchen
  YL=Val(Mid(Str(SLASTZUGA),2,1))      ;liefert die Linie (1 bis 8) des Ausgangsfeldes
  ZL=Val(Mid(Str(SLASTZUGZ),2,1))      ;liefert die Linie (1 bis 8) des Zielfeldes    
  If XB=$81                            ;XB ist noch schwarze Figur, Test auf Bauer
    *SBSTELL\Pos[SLASTZUGA] ! $80      ;diesen Bauer in SBSTELL lschen (XOR!)
    *SBSTELL\Pos[SLASTZUGA+9]-1        ; XOR $80 lsst die Einflussfelder unberhrt
    *SBSTELL\Pos[SLASTZUGA+11]-1       ;die beiden Einflussfelder verringern
    *SBLINIE\Pos[YL]-1                 ;auf Ausgangsfeld-Linie ein weisser Bauer weniger    
    ;hier Test auf Bauernumwandlung
    If SLASTZUGZ >= 91                 ;1.Reihe?
      *ANZBAUERS\Mat[Tiefe]-1          ;Bauer weg
      *ASTELL\Feld[SLASTZUGZ] = $85    ;schwarze Dame setzen
      *MATS\Mat[Tiefe]+875             ;875=Dame-Bauer
     Else 
      ZB=SLASTZUGZ-SLASTZUGA           ;10 oder 20 wren "normale" Bauernschritte
      ;jetzt Test auf en passant    
      If YB=0 And (ZB=9 Or ZB=11)      ;war das Zielfeld leer und wurde trotzdem geschlagen?
        *ASTELL\Feld[SLASTZUGZ-10] & $40    ;den weissen e.p.-Bauern entfernen, nur Feldfarbe bleibt  
        *ANZFIGW\Mat[Tiefe]-1          ;eine weisse Figur weg  
        *ANZBAUERW\Mat[Tiefe]-1        ;Bauer auch weg
        *MATW\Mat[Tiefe]-100           ;Material um Bauernwert (=100) reduzieren
        *WBSTELL\Pos[SLASTZUGZ-10] ! $10     ;diesen Bauer in WBSTELL lschen (XOR!)
        *WBSTELL\Pos[SLASTZUGZ-19]-1   ;die beiden Einflussfelder verringern 
        *WBSTELL\Pos[SLASTZUGZ-21]-1
        *WBLINIE\Pos[ZL]-1             ;auf dieser Linie ein weisser Bauer weniger
      EndIf 
      *SBLINIE\Pos[ZL]+1               ;auf Zielfeld-Linie ein schwarzer Bauer mehr
      *SBSTELL\Pos[SLASTZUGZ] ! $80    ;diesen Bauer in SBSTELL setzen (XOR!)       
      *SBSTELL\Pos[SLASTZUGZ+9]+1      ; XOR $80 lsst die Einflussfelder unberhrt
      *SBSTELL\Pos[SLASTZUGZ+11]+1     ;die beiden Einflussfelder erhhen
    EndIf 

   ElseIf XB=$84                       ;Turm?
    *STLINIE\Pos[YL]-1                 ;von Linie Ausgangsfeld weg
    *STLINIE\Pos[ZL]+1                 ;auf Linie Zielfeld hinzu  

   ElseIf XB=$86                       ;Knig? 
    SKFELD=SLASTZUGZ                   ;aktualisieren 
    SKLINIE=Val(Mid(Str(SLASTZUGZ),2,1))    ;liefert die Linie (1 bis 8) des Zielfeldes
    ZL=SLASTZUGZ-SLASTZUGA
    If ZL=2                            ;dann ist es kleine Rochade (-2 = grosse)
      RochStatusS=1
      *ASTELL\Feld[28]=0               ;Turm H8 lschen
      *STLINIE\Pos[8]-1
      *ASTELL\Feld[26]=$84             ;Turm F8 hinzufgen
      *STLINIE\Pos[6]+1     
     ElseIf ZL=-2                      ;grosse Rochade 
      RochStatusS=2
      *ASTELL\Feld[21]=0               ;Turm A8 lschen
      *STLINIE\Pos[1]-1
      *ASTELL\Feld[24]=$84             ;Turm D8 hinzufgen
      *STLINIE\Pos[4]+1     
    EndIf 
  EndIf 

AZ+438                                 ;neuer Zeiger in ZugTab
Color=0                                ;Weiss jetzt am Zug
EndIf 
EndProcedure
;--------------------------------------------------------------------------------------------------
Procedure ZSZ()                        ;schwarzen Zug intern zurcknehmen
XB= *AFELD\Prog[Tiefe]                 ;AFeld und ZFeld zurckholen
YB= *ZFELD\Prog[Tiefe]

ZB= *ZFELDH\Prog[Tiefe]
*ASTELL\Feld[YB]=ZB                    ;Inhalt vom Zielfeld komplett zurck

YL=Val(Mid(Str(XB),2,1))               ;liefert die Linie (1 bis 8) des Ausgangsfeldes
ZL=Val(Mid(Str(YB),2,1))               ;liefert die Linie (1 bis 8) des Zielfeldes    
ZB & 7                                 ;Inhalt Zielfeld
WB=ZB                                  ;fr spteren Test auf e.p.
If ZB=1                                ;wurde weisser Bauer geschlagen?
  *WBSTELL\Pos[YB] ! $10               ;wieder setzen
  *WBSTELL\Pos[YB-9]+1                 ;die beiden Einflussfelder wieder erhhen 
  *WBSTELL\Pos[YB-11]+1
  *WBLINIE\Pos[ZL]+1                   ;auf dieser Linie ein weisser Bauer wieder mehr
 ElseIf ZB=4                           ;wurde weisser Turm geschlagen?
  *WTLINIE\Pos[ZL]+1                   ;auf Linie Zielfeld wieder hinzu 
EndIf 

ZB= *AFELDH\Prog[Tiefe]
*ASTELL\Feld[XB]=ZB                    ;Inhalt vom Ausgangsfeld komplett zurck
ZB & 7                                 ;Figur auf Ausgangsfeld
If ZB=1                                ;eigener (schwarzer) Bauernzug?
  *SBSTELL\Pos[XB] ! $80               ;diesen Bauer in SBSTELL setzen (XOR!)       
  *SBSTELL\Pos[XB+9]+1                 ;die beiden Einflussfelder erhhen
  *SBSTELL\Pos[XB+11]+1
  If YB>=91                            ;Bauernumwandlung?
    *SBLINIE\Pos[YL]+1                 ;mehr nicht!
   ElseIf YB<91 
    *SBSTELL\Pos[YB] ! $80             ;Bauer in SBSTELL lschen (XOR!)
    *SBSTELL\Pos[YB+9]-1               ;die beiden Einflussfelder verringern
    *SBSTELL\Pos[YB+11]-1   
    If WB=0                            ;Zielfeld leer wegen Test auf e.p. ?
      VB=YB-XB                         ;Differenz ZFeld-AFeld
      If VB=9 Or VB=11                 ;dann war es e.p.
        *ASTELL\Feld[YB-10] | $11      ;den weissen e.p.-Bauern wieder rein
        *WBSTELL\Pos[YB-10] ! $10      ;wieder setzen
        *WBSTELL\Pos[YB-19]+1          ;die beiden Einflussfelder wieder erhhen 
        *WBSTELL\Pos[YB-21]+1
        *WBLINIE\Pos[ZL]+1             ;auf dieser Linie ein weisser Bauer wieder mehr     
        *SBLINIE\Pos[ZL]-1 
        *SBLINIE\Pos[YL]+1  
      EndIf
     ElseIf WB<>0                      ;Zielfeld war nicht leer, also Schlagzug
      *SBLINIE\Pos[ZL]-1 
      *SBLINIE\Pos[YL]+1
    EndIf  
  EndIf 
 
 ElseIf ZB=4                           ;Turm?
 *STLINIE\Pos[ZL]-1                    ;von Linie Zielfeld weg
 *STLINIE\Pos[YL]+1                    ;auf Linie Ausgangsfeld hinzu  
 
 ElseIf ZB=6                           ;Knig?
  SKFeld=XB                            ;wieder Ausgangsfeld 
  SKLinie=YL
  VB=YB-XB                             ;Differenz ZFeld-AFeld
  If VB=2                              ;kleine Rochade
    RochStatusS=0
    *ASTELL\Feld[28]=$C4               ;Turm H8 wieder rein
    *ASTELL\Feld[26]=$40               ;Turm F8 wieder weg  
    *STLINIE\Pos[6]-1
    *STLINIE\Pos[8]+1     
   ElseIf VB=254                       ;grosse Rochade
    RochStatusS=0
    *ASTELL\Feld[21]=$84               ;Turm A8 wieder rein
    *ASTELL\Feld[24]=$40               ;Turm D8 wieder weg    
    *STLINIE\Pos[4]-1
    *STLINIE\Pos[1]+1     
  EndIf 
EndIf 

Tiefe-1                                ;eine Rechentiefe wieder zurck
AZ-438                                 ;Zeiger in ZugTab wieder (hier) auf schwarze Zge
Color=128                              ;Schwarz wieder am Zug
EndProcedure
;--------------------------------------------------------------------------------------------------
Procedure BWS()                        ;Bewertungs-Funktion, Werte aus der Sicht von Weiss!
   ZST+1
If Color
  ZFeldZ=WKFeld                        ;Weiss muss Zug ausfhren
  AttackFeldS()
  If Attack
    MPW=$F532                          ;Weiss steht selbst im Schach
    MPW-Tiefe
    Goto BWSEnd1
   Else
    ZFeldZ=SKFeld                      ;ob Weiss Schach bietet
    AttackFeldW()    
  EndIf 
 Else 
  ZFeldZ=SKFeld                        ;Schwarz muss Zug ausfhren
  AttackFeldW()
  If Attack
    MPW=$F532                          ;Schwarz steht selbst im Schach
    MPW-Tiefe    
    Goto BWSEnd1
   Else
    ZFeldZ=WKFeld                      ;ob Schwarz Schach bietet
    AttackFeldS()    
  EndIf   
EndIf 

;Test auf technisches Remis
;liefert dann Wert = 0 zurck

;Stellungswert ermitteln
MPW=$8000                              ;Startwert +-0, immer aus der Sicht von Weiss!
;erstmal Materialbilanz aller Figuren 
MPW + *MATW\Mat[Tiefe]
MPW - *MATS\Mat[Tiefe]
;Festlegung, ob Endspiel oder nicht
XL = *ANZFIGW\Mat[Tiefe] - *ANZBAUERW\Mat[Tiefe]
YL = *ANZFIGS\Mat[Tiefe] - *ANZBAUERS\Mat[Tiefe]
If XL>3 Or YL>3 
  Endspiel=0
 Else 
  Endspiel=1
EndIf
;jetzt die Stellungs-Feinheiten
XL = *ANZFIGW\Mat[Tiefe]               ;wieviel Figuren sind berhaupt noch da? 
XL + *ANZFIGS\Mat[Tiefe]
XL-2                                   ;Knige weg

For i=98 To 21 Step -1                 ;von Feld H1 bis A8
  If XL>0                              ;wenn noch Figur da ist
    XB = *ASTELL\Feld[i]               ;ASTELL abklappern
    XB & %10010111                     ;Test welche Figur
    If XB = $11                        ;weisser Bauer
      XL-1      
      MPW + *WBAUER\Pos[i]
      If (*WBSTELL\Pos[i-10] & 3) > 0 
        MPW + 5                        ;Bonus fr Bauern-Duo (oder Trio!) 
      EndIf 
      If (*WBSTELL\Pos[i] & 3) > 0 
        MPW + 10                       ;Bonus fr untersttzten Bauern 
      EndIf 
     ElseIf XB = $81                   ;schwarzer Bauer 
      XL-1      
      MPW - *SBAUER\Pos[i]
      If (*SBSTELL\Pos[i-10] & 3) > 0 
        MPW - 5                        ;Malus fr Bauern-Duo (oder Trio!) 
      EndIf      
      If (*SBSTELL\Pos[i] & 3) > 0 
        MPW - 10                       ;Malus fr untersttzten Bauern 
      EndIf     
     ElseIf XB = $12                   ;weisser Springer
      XL-1      
      MPW + *ENTWICKLUNG\Pos[i]
     ElseIf XB = $82                   ;schwarzer Springer 
      XL-1      
      MPW - *ENTWICKLUNG\Pos[i]
     ElseIf XB = $13                   ;weisser Lufer
      XL-1      
      MPW + *ENTWICKLUNG\Pos[i]
     ElseIf XB = $83                   ;schwarzer Lufer 
      XL-1      
      MPW - *ENTWICKLUNG\Pos[i]
    EndIf 
  EndIf 
Next

;Knigsstellung (im Endspiel nicht)
If Endspiel=0
  MPW - *ENTWICKLUNG\Pos[WKFELD]       ;damit der Knig nicht ins Zentrum marschiert  
  MPW + *ENTWICKLUNG\Pos[SKFELD]
  If RochStatusW = 1
     MPW + 20                          ;Bonus fr kleine Rochade     
   ElseIf RochStatusW = 2
     MPW + 15                          ;Bonus fr grosse Rochade
  EndIf  
  If RochStatusS = 1
     MPW - 20
   ElseIf RochStatusS = 2
     MPW - 15
  EndIf 
EndIf

For i=1 To 8
  If *WTLINIE\Pos[i] = 2
    MPW + 15                           ;Bonus fr Turmverdopplung
    If *WBLINIE\Pos[i] = 0
      MPW + 15                         ;Bonus fr halboffene Turmlinie
      If *SBLINIE\Pos[i] = 0
        MPW + 15                       ;Bonus fr offene Turmlinie 
      EndIf
    EndIf 
    If SKLINIE = i
      MPW + 20                         ;Bonus fr Trme auf Knigslinie
    EndIf 
   ElseIf *WTLINIE\Pos[i] = 1
    MPW + 10                           ;Bonus fr Turmverdopplung
    If *WBLINIE\Pos[i] = 0
      MPW + 10                         ;Bonus fr halboffene Turmlinie
      If *SBLINIE\Pos[i] = 0
        MPW + 10                       ;Bonus fr offene Turmlinie 
      EndIf
    EndIf 
    If SKLINIE = i
      MPW + 15                         ;Bonus fr Turm auf Knigslinie
    EndIf     
  EndIf 
  
  If *STLINIE\Pos[i] = 2
    MPW - 15                           ;Malus fr Turmverdopplung
    If *SBLINIE\Pos[i] = 0
      MPW - 15                         ;Malus fr halboffene Turmlinie
      If *WBLINIE\Pos[i] = 0
        MPW - 15                       ;Malus fr offene Turmlinie 
      EndIf
    EndIf 
    If WKLINIE = i
      MPW - 20                         ;Malus fr Trme auf Knigslinie
    EndIf 
   ElseIf *STLINIE\Pos[i] = 1
    MPW - 10                           ;Malus fr Turmverdopplung
    If *SBLINIE\Pos[i] = 0
      MPW - 10                         ;Malus fr halboffene Turmlinie
      If *WBLINIE\Pos[i] = 0
        MPW - 10                       ;Malus fr offene Turmlinie 
      EndIf
    EndIf 
    If WKLINIE = i
      MPW - 15                         ;Malus fr Turm auf Knigslinie
    EndIf       
  EndIf  
  
  If *WBLINIE\Pos[i] > 1
    MPW - 15                           ;Malus fr Doppelbauern (oder mehr)
  EndIf   

  If *SBLINIE\Pos[i] > 1
    MPW + 15                           ;Bonus fr Doppelbauern (oder mehr)
  EndIf     
  
  If *WBLINIE\Pos[i] = 1 And i > 1 And i < 8
    If *WBLINIE\Pos[i-1] = 0 And *WBLINIE\Pos[i+1] = 0
      MPW - 25                         ;Malus fr Einzelbauer
    EndIf
  EndIf

  If *SBLINIE\Pos[i] = 1 And i > 1 And i < 8
    If *SBLINIE\Pos[i-1] = 0 And *SBLINIE\Pos[i+1] = 0
      MPW + 25                         ;Bonus fr Einzelbauer
    EndIf
  EndIf
Next

BWSEnd:
If Color
  MPW = ((~MPW)+1) & $FFFF             ;NEG fr Schwarz 
 Else 
  MPW & $FFFF
EndIf
BWSEnd1:
EndProcedure
;--------------------------------------------------------------------------------------------------
Procedure ALPHABETA()                  ;Alpha-Beta
BWS()                                  ;Stellung bewerten
If MPW=0                               ;z.B.technisches Remis
  MPW=$8000
  Goto ABEnd
 ElseIf MPW>=$F500                     ;Matt("verdacht") 
  *TIEFENWERT\Prog[Tiefe] = MPW
  Goto ABEnd1
EndIf   
 
If Tiefe < 31                          ;u.a.Structure-Grsse
  *SCHACH\Prog[Tiefe]=Attack           ;Attack von BWS
  ;Erweiterungen der Suchtiefe festlegen
  If *VARTIEFE\Prog[Tiefe] >= 0 And Tiefe < 20 And *ERWEITERUNG\Prog[Tiefe] < 600   ;nicht, wenn in Ruhesuche Tiefe grsser 20 oder schon zuviel Erweiterungen
    If Attack                          ;wenn Schach-Gebot
      *ERWEITERUNG\Prog[Tiefe] + $10
    EndIf
    If Attack=0 And *ZFELD\Prog[Tiefe] = *ZFELD\Prog[Tiefe-1]   ;beiden letzten Zielfelder identisch?
      YL = *ZFELDH\Prog[Tiefe-1] & 7   ;stand Figur auf Zielfeld?
      If Tiefe < 12 And YL   
        *ERWEITERUNG\Prog[Tiefe] + 8
      EndIf 
    EndIf 
  EndIf

  XB = *ERWEITERUNG\Prog[Tiefe]        ;so wegen Byte! 
  If XB >= $10  
    *ERWEITERUNG\Prog[Tiefe] + $F0     ;sub $10 und add $100
    *VARTIEFE\Prog[Tiefe] + 1          ;Suche vertiefen
  EndIf 

  If *VARTIEFE\Prog[Tiefe] >= -5       ;also maximale Ruhesuch-Tiefe = 5
  ;Test auf Vorwrts-Abschneidung
    If Attack=0 And *VARTIEFE\Prog[Tiefe] <= 1 And MPW >= *BETA\Prog[Tiefe]
      *TIEFENWERT\Prog[Tiefe] = MPW
      Goto ABEnd1 
    EndIf 
   
    If Color
      ZugGens()
     Else
      If ElapsedMilliseconds()-Time >= ZugZeit   ;hier eingestreut
        TimeOut=1
        Goto ABEnd1 
      EndIf 
      ZugGenw() 
    EndIf

    ;Startwerte setzen
    If *VARTIEFE\Prog[Tiefe] > 0
      *BESTERWERT\Prog[Tiefe] = $0ACE
     Else 
      *BESTERWERT\Prog[Tiefe] = MPW    ;Wert fr Ruhesuche
    EndIf 

NextZug: 
    If Color
      ASZ()
      If XB=$FF                        ;Ende der Zugtabelle?    
        Goto Pattsuche                 ;also kein Zug ausgefhrt!
      EndIf 
     Else
      AWZ()
      If XB=$FF
        Goto Pattsuche
      EndIf    
    EndIf  
      
    *BETA\Prog[Tiefe] = (~(*ALPHA\Prog[Tiefe-1])+1) & $FFFF     ;NEG und Klimmzug unsigned
    *ALPHA\Prog[Tiefe] = (~(*BETA\Prog[Tiefe-1])+1) & $FFFF
    *VARTIEFE\Prog[Tiefe] = *VARTIEFE\Prog[Tiefe-1]-1
    ALPHABETA()
    If Color
      ZWZ()
     Else
      ZSZ() 
    EndIf   

    MPW = (~(*TIEFENWERT\Prog[Tiefe+1])+1) & $FFFF    ;NEG
    If MPW > *BESTERWERT\Prog[Tiefe]
      *BESTERWERT\Prog[Tiefe] = MPW    ;neuer bester Wert    
     Else
      Goto NextZug                     ;nchsten Zug ausfhren
    EndIf 
  
    If MPW >= *BETA\Prog[Tiefe]
      Goto Fertig                      ;Cutoff, dieser Zweig kann hier verlassen werden
     Else
      If MPW <= *ALPHA\Prog[Tiefe]
        Goto NextZug
       Else 
        *ALPHA\Prog[Tiefe] = MPW       ;neuer Wert fr Alpha
        Goto NextZug      
      EndIf 
    EndIf 
  
Fertig:  
    If MPW < *BETA\Prog[Tiefe] 
      Goto ABEnd
     Else                              ;neuer Killerzug (bester Zug in einer Variante)
      *KILLERZUG2A\ZugGen[Tiefe] = *KILLERZUG1A\ZugGen[Tiefe]   ;fr ZugGen
      *KILLERZUG2Z\ZugGen[Tiefe] = *KILLERZUG1Z\ZugGen[Tiefe]
      *KILLERZUG1A\ZugGen[Tiefe] = *AFELD\Prog[Tiefe+1] 
      *KILLERZUG1Z\ZugGen[Tiefe] = *ZFELD\Prog[Tiefe+1]
    EndIf 
    Goto ABEnd
   
Pattsuche:   
    XL=$0ACF                           ;tiefster Wert+1
    XL+Tiefe
    If XL <> *BESTERWERT\Prog[Tiefe]
      Goto ABEnd
     Else
      If *SCHACH\Prog[Tiefe] <> 0
        Goto ABEnd
       Else
        *TIEFENWERT\Prog[Tiefe] = $8000     ;Patt!
        Goto ABEnd1
      EndIf  
    EndIf    
   
  EndIf 

*TIEFENWERT\Prog[Tiefe] = MPW
Goto ABEnd1
EndIf

ABEnd:
*TIEFENWERT\Prog[Tiefe] = *BESTERWERT\Prog[Tiefe]     ;Rckgabewert
ABEnd1:
EndProcedure
;--------------------------------------------------------------------------------------------------
;Brett darstellen und Brettbeschriftung
j=0
For i=1 To 8
  TextGadget(100+i, 5, 290-j, 7, 12, Str(i))
  TextGadget(110+i, 32+j, 318, 7, 12, Chr(i+64))
  j+38
Next   

;- optische Anzeige wer am Zug
TextGadget(200, 322, 290, 12, 12, "  ")               ;Weiss
BGFarbe=GetGadgetColor(200, #PB_Gadget_BackColor)     ;Hintergrundfarbe sichern
SetGadgetColor(200, #PB_Gadget_BackColor, RGB(255,255,255))
TextGadget(201, 322, 22, 12, 12, "  ")                ;Schwarz
SetGadgetColor(201, #PB_Gadget_BackColor, BGFarbe)

BrettMal()                             ;aktuelle Stellung zeichnen

;-------------------------
Repeat
  Event = WaitWindowEvent()
  If Color=0                           ;also Weiss am Zug, warten auf Zugeingabe
    Select Event
      Case #PB_Event_Gadget
        Ima=EventGadget()
        Inhalt=GetGadgetState(Ima)
       
        If Rand
          Rand=0
          ImageGadget(ImaSi, XImaSi, YImaSi, 38, 38, InhaltSi, Rand)
          WLastZugZ=Ima   
         Else 
          XB = *ASTELL\Feld[Ima]       ;Ausgangsfeld auslesen
          XB & %00010000               ;Test ob weisse Figur 
          If XB=0
            Rand=0
           Else 
            Rand=#PB_Image_Border
            WLastZugA=Ima
          EndIf  
        EndIf
       
        ;X-Koordinate des angeklickten Feldes (Images) ermitteln
        X=(Val(Mid(Str(Ima),2,1))-1)
        XIma=15+(X*38)
        ;Y-Koordinate des angeklickten Feldes (Images) ermitteln
        Y=(Val(Mid(Str(Ima),1,1))-2) 
        YIma=10+(Y*38)
      
        ImageGadget(Ima, XIma, YIma, 38, 38, Inhalt, Rand)

        If Rand
          ImaSi=Ima
          XImaSi=XIma
          YImaSi=YIma
          InhaltSi=Inhalt
        EndIf 
 
        If WLastZugA=WLastZugZ
          WLastZugA=0:WLastZugZ=0
         ElseIf WLastZugA<>0 And WLastZugZ<>0
          YB = *ASTELL\Feld[WLastZugZ]      ;Zielfeld auslesen
          YB & %00010000                    ;Test ob weisse Figur
          If YB=0
            Gueltig=1                       ;erstmal grob
            Color=128
           Else
            Beep_(1000, 250)
            WLastZugA=0 : WLastZugZ=0
          EndIf
        EndIf 
    EndSelect

   Else                      ;Programm am Zug bzw. berprfung, ob Zug vom Gegner legal ist
    ZugGenW()                ;Tabelle mit weisse Zgen erstellen, evtl, nur einmal aufrufen
    j=0
    k=(ZZ-2)/2               ;ZZ noch von ZugGenW()
    For i=0 To k             ;Zugtabelle mit eingegben Zug vergleichen
      XB=*ZUGTAB\ZugGen[j]
      j+1
      YB=*ZUGTAB\ZugGen[j]
      j+1      
      If XB=WLastZugA And YB=WLastZugZ
        Break                ;Zug gltig
      EndIf 
    Next
    
    If i>k                   ;Zug ungltig
      Beep_(1000, 250)
      Color=0
      WLastZugA=0 : WLastZugZ=0   
      Gueltig=0
    EndIf 
  
    If Gueltig               ;jetzt noch testen, ob Weiss nach seinem Zug nicht im Schach steht
      *Z\ZugGen[0]=j-2       ;j noch von oben, zeigt auf den ausgefhrten Zug  
      AWZ()                  ;weissen Zug ausfhren
      ZFeldZ=WKFeld
      AttackfeldS()          ;hier noch Test ntig, ob Weiss im Schach steht. In der Suche
                             ; wird dies in der Bewertungsfunktion erledigt  
      If Attack
        Beep_(1000, 250)
        Gueltig=0            ;Weiss steht nach seinem Zug im Schach! Also ungltig
        ZWZ()                ;der ausgefhrte weisse Zug muss wieder zurckgenommen werden!
        WLastZugA=0 : WLastZugZ=0
      EndIf
    EndIf 

    If Gueltig               ;jetzt endgltig
      *ANZFIGS\Mat[0] = *ANZFIGS\Mat[1]     ;Werte noch von AWZ oben
      *ANZBAUERS\Mat[0] = *ANZBAUERS\Mat[1]
      *ANZFIGW\Mat[0] = *ANZFIGW\Mat[1]
      *ANZBAUERW\Mat[0] = *ANZBAUERW\Mat[1]
      *MATW\Mat[0] = *MATW\Mat[1]
      *MATS\Mat[0] = *MATS\Mat[1]   
     
      Time=ElapsedMilliseconds()
      ;ab hier rechnet das Programm      
      Gueltig=0      
      ;Brettdarstellung aktualisieren     
      BrettMal()                                           ;neue Brettsituation darstellen  
      ;optische Darstellung Schwarz am Zug
      SetGadgetColor(200, #PB_Gadget_BackColor, BGFarbe)   ;Weiss
      SetGadgetText(200, "  ")
      SetGadgetColor(201, #PB_Gadget_BackColor, 0)         ;Schwarz
      SetGadgetText(201, "  ")
 
      AZ=0
      Tiefe=0
      *VARTIEFE\Prog[0]=0    
      ZugGenS()                        ;schwarze Zge generieren  Test auf Anzahl, Schach, Matt 
      *ALPHA\Prog[0]=$0ACE             ;tiefster Wert, Startwert fr 1.Zug
      *BETA\Prog[0]=$F532              ;hchster Wert, Startwert fr 1.Zug
      ;nchste Suchtiefe, Hauptschleife 
      While *VARTIEFE\Prog[0]<=31 And TimeOut=0
        ;Anfangswerte setzen
        *VARTIEFE\Prog[0]+1        
        *Z\ZugGen[0]=0                 ;Zeiger in die schwarze Zugtabelle
        If *VARTIEFE\Prog[0]>1         ;wenn nicht Anfang bereits vorhandene Werte nutzen
          ZL=*ALPHA\Prog[0]
          ZL+80
          XL=*VARTIEFE\Prog[0]
          XL<<1
          ZL-XL
          *BETA\Prog[0]=ZL
          ZL-160
          ZL+XL
          *ALPHA\Prog[0]=ZL
        EndIf       

        ;nchster Zug der Ausgangsstellung
        YL=AZ + *Z\ZugGen[0]

        While *ZUGTAB\ZugGen[YL]<>$FF And TimeOut=0   ;noch Zug da?       
          *ERWEITERUNG\Prog[0]=0
          ASZ()                        ;schwarzen Zug ausfhren
          *BETA\Prog[1] = (~(*ALPHA\Prog[0])+1) & $FFFF    ;NEG
          *ALPHA\Prog[1] = (~(*BETA\Prog[0])+1) & $FFFF
          *VARTIEFE\Prog[1] = *VARTIEFE\Prog[0]-1
          ALPHABETA()
          ZSZ()                        ;schwarzen Zug zurcknehmen
          ;Auswertung
          *TIEFENWERT\Prog[0] = (~(*TIEFENWERT\Prog[1])+1) & $FFFF
          *ERWEITERUNG\Prog[0] = 0
          If *Z\ZugGen[0] = 2          ;1.Zug der Ausgangsstellung
            If *TIEFENWERT\Prog[0] < *ALPHA\Prog[0]   ;Fail-Low, Wert ist schlechter als der vorhandene  
              *ALPHA\Prog[0] = $0ACE
              *BETA\Prog[0] = *TIEFENWERT\Prog[0]
              *ALPHA\Prog[1] = (~(*BETA\Prog[0])+1) & $FFFF
              *BETA\Prog[1] = $F532
              *VARTIEFE\Prog[1] = *VARTIEFE\Prog[0]-1
              *Z\ZugGen[0] = 0         ;1.Zug noch einmal durchackern
              ASZ()                    ;schwarzen Zug ausfhren
              ALPHABETA()              ;neue Berechnung wegen Fail-Low
              *TIEFENWERT\Prog[0] = (~(*TIEFENWERT\Prog[1])+1) & $FFFF             
              ZSZ()                    ;schwarzen Zug zurcknehmen
             ElseIf *TIEFENWERT\Prog[0] >= *BETA\Prog[0]  ;Fail-High, Wert ist besser als der vorhandene
              *ALPHA\Prog[0] = *TIEFENWERT\Prog[0]
              *BETA\Prog[0] = $F532
              *ALPHA\Prog[1] = $0ACE
              *BETA\Prog[1] = (~(*ALPHA\Prog[0])+1) & $FFFF
              *VARTIEFE\Prog[1] = *VARTIEFE\Prog[0]-1
              *Z\ZugGen[0] = 0         ;1.Zug noch einmal durchackern
              ASZ()                    ;schwarzen Zug ausfhren
              ALPHABETA()              ;neue Berechnung wegen Fail-High
              ZSZ()                    ;schwarzen Zug zurcknehmen            
            EndIf  
           ;Nullwindow     
            *TIEFENWERT\Prog[0] = (~(*TIEFENWERT\Prog[1])+1) & $FFFF        
            *ALPHA\Prog[0] = *TIEFENWERT\Prog[0]           
            *BETA\Prog[0] = *ALPHA\Prog[0] + 1  ;Nullwindow, Beta nur um 1 grsser als Alpha
           Else  
            If *TIEFENWERT\Prog[0] > *ALPHA\Prog[0]
              *BESTERWERT\Prog[0] = *ALPHA\Prog[0]
              *ALPHA\Prog[0] = *TIEFENWERT\Prog[0]
              *BETA\Prog[0] = $F532
              *ALPHA\Prog[1] = $0ACE
              *BETA\Prog[1] = (~(*ALPHA\Prog[0])+1) & $FFFF
              *VARTIEFE\Prog[1] = *VARTIEFE\Prog[0]-1
              *Z\ZugGen[0] - 2         ;selben Zug noch einmal durchackern
              ASZ()                    ;schwarzen Zug ausfhren
              ALPHABETA()              ;neue Berechnung
              ZSZ()                    ;schwarzen Zug zurcknehmen 
              *TIEFENWERT\Prog[0] = (~(*TIEFENWERT\Prog[1])+1) & $FFFF
              If *TIEFENWERT\Prog[0] > *BESTERWERT\Prog[0]
                *ALPHA\Prog[0] = *TIEFENWERT\Prog[0]
                *BETA\Prog[0] = *ALPHA\Prog[0] + 1
                ;diesen Zug jetzt an die Spitze der Zugtabelle setzen
                Swap *ZUGTAB\ZugGen[0], *ZUGTAB\ZugGen[*Z\ZugGen[0]-2]    ;oder komplette Verschiebung
                Swap *ZUGTAB\ZugGen[1], *ZUGTAB\ZugGen[*Z\ZugGen[0]-1]
              EndIf
            EndIf
          EndIf
          YL=AZ + *Z\ZugGen[0]         ;Zeiger auf nchsten schwarzen Zug
        Wend  
      
        If *ALPHA\Prog[0] = $0ACF 
          ZFeldZ=SKFeld
          AttackFeldW() 
          If Attack
            SetGadgetText(200, "M!")   ;Schwarz ist matt       
           Else 
            SetGadgetText(200, "P!")
          EndIf 
          TimeOut=0 
          Break           
        EndIf 
hWnd=GetForegroundWindow_()
String$="T= "+Str(*VARTIEFE\Prog[0])+"  W= "+Hex(*ALPHA\Prog[0])+"   "+Str(ZST)+"  "+Str(ZST*1000/(ElapsedMilliseconds()-Time))
pString=@String$
SetWindowText_(hWnd, pString)
      Wend 
ZST=0 
      ;Schwarz fhrt seinen Zug aus, wenn nicht Matt oder Patt
      If *ALPHA\Prog[0] <> $0ACF 
        *Z\ZugGen[0]=0       ;der in der Zugtabelle an 1.Stelle stehende Zug wird ausgefhrt
        ASZ()
        If *ALPHA\Prog[0] = $F530
          Beep_(1000, 250)
          ZFeldZ=WKFeld
          AttackFeldS()
          If Attack
            SetGadgetText(201, "M!")   ;Weiss ist matt           
           Else 
            SetGadgetText(201, "P!")    
          EndIf 
        EndIf 
      EndIf  
      ;wieder Startwerte fr Weiss
      TimeOut=0
      Tiefe=0
      AZ=0
      *Z\ZugGen[0]=0      
      *ANZFIGS\Mat[0] = *ANZFIGS\Mat[1]
      *ANZBAUERS\Mat[0] = *ANZBAUERS\Mat[1]
      *ANZFIGW\Mat[0] = *ANZFIGW\Mat[1]
      *ANZBAUERW\Mat[0] = *ANZBAUERW\Mat[1]
      *MATW\Mat[0] = *MATW\Mat[1]
      *MATS\Mat[0] = *MATS\Mat[1]
      BrettMal() 
      SetGadgetColor(200, #PB_Gadget_BackColor, RGB(255,255,255))
      SetGadgetColor(201, #PB_Gadget_BackColor, BGFarbe)               
      WLastZugA=0 : WLastZugZ=0
    EndIf 
  EndIf 
Until Event = #PB_Event_CloseWindow
;----------------------------------------------------------------------------------------
DataSection
KRicht:                                ;die 8 Zugmglichkeiten des Knigs (ohne Rochade)
  Data.l -9, 1, 11, 10, 9, -1, -11, -10
SRicht:                                ;die 8 Zugmglichkeiten des Springers
  Data.l -19, -8, 12, 21, 19, 8, -12, -21
LRicht:                                ;die 4 Zugmglichkeiten des Lufers/Dame
  Data.l -9, -11, 9, 11
TRicht:                                ;die 4 Zugmglichkeiten des Turms/Dame
  Data.l -10, -1, 10, 1
FigWert:                               ;die Materialwerte der einzelnen Figuren
  Data.l 0, 100, 325, 326, 500, 975   ;keine Figur, Bauer, Springer, Lufer, Turm, Dame
ASTELLX:                                ;aktuelle Stellung, Start mit Grundstellung
  Data.b $08, $08, $08, $08, $08, $08, $08, $08, $08, $08
  Data.b $08, $08, $08, $08, $08, $08, $08, $08, $08, $08
  Data.b $08, $40, $00, $40, $00, $86, $40, $00, $40, $08
  Data.b $08, $40, $00, $40, $00, $40, $00, $40, $00, $08
  Data.b $08, $00, $40, $00, $40, $00, $40, $00, $40, $08
  Data.b $08, $40, $00, $40, $00, $40, $00, $40, $00, $08
  Data.b $08, $00, $40, $00, $40, $00, $40, $00, $40, $08
  Data.b $08, $40, $00, $40, $00, $40, $00, $40, $00, $08
  Data.b $08, $11, $51, $11, $51, $11, $51, $11, $51, $08
  Data.b $08, $54, $12, $53, $15, $56, $13, $52, $14, $08
  Data.b $08, $08, $08, $08, $08, $08, $08, $08, $08, $08
  Data.b $08, $08, $08, $08, $08, $08, $08, $08, $08, $08                
ASTELL:                                ;aktuelle Stellung, Start mit Grundstellung
  Data.b $08, $08, $08, $08, $08, $08, $08, $08, $08, $08
  Data.b $08, $08, $08, $08, $08, $08, $08, $08, $08, $08
  Data.b $08, $84, $c2, $83, $c5, $86, $c3, $82, $c4, $08
  Data.b $08, $c1, $81, $c1, $81, $c1, $81, $c1, $81, $08
  Data.b $08, $00, $40, $00, $40, $00, $40, $00, $40, $08
  Data.b $08, $40, $00, $40, $00, $40, $00, $40, $00, $08
  Data.b $08, $00, $40, $00, $40, $00, $40, $00, $40, $08
  Data.b $08, $40, $00, $40, $00, $40, $00, $40, $00, $08
  Data.b $08, $11, $51, $11, $51, $11, $51, $11, $51, $08
  Data.b $08, $54, $12, $53, $15, $56, $13, $52, $14, $08
  Data.b $08, $08, $08, $08, $08, $08, $08, $08, $08, $08
  Data.b $08, $08, $08, $08, $08, $08, $08, $08, $08, $08 
WBSTELL:                               ;weisse Bauernstruktur
  Data.b $08, $08, $08, $08, $08, $08, $08, $08, $08, $08
  Data.b $08, $08, $08, $08, $08, $08, $08, $08, $08, $08
  Data.b $08, $00, $00, $00, $00, $00, $00, $00, $00, $08
  Data.b $08, $00, $00, $00, $00, $00, $00, $00, $00, $08
  Data.b $08, $00, $00, $00, $00, $00, $00, $00, $00, $08
  Data.b $08, $00, $00, $00, $00, $00, $00, $00, $00, $08
  Data.b $08, $00, $00, $00, $00, $00, $00, $00, $00, $08
  Data.b $08, $01, $02, $02, $02, $02, $02, $02, $01, $08
  Data.b $08, $10, $10, $10, $10, $10, $10, $10, $10, $08
SBSTELL:                               ;schwarze Bauernstruktur
  Data.b $08, $08, $08, $08, $08, $08, $08, $08, $08, $08
  Data.b $08, $08, $08, $08, $08, $08, $08, $08, $08, $08
  Data.b $08, $00, $00, $00, $00, $00, $00, $00, $00, $08
  Data.b $08, $80, $80, $80, $80, $80, $80, $80, $80, $08
  Data.b $08, $01, $02, $02, $02, $02, $02, $02, $01, $08
  Data.b $08, $00, $00, $00, $00, $00, $00, $00, $00, $08
  Data.b $08, $00, $00, $00, $00, $00, $00, $00, $00, $08
  Data.b $08, $00, $00, $00, $00, $00, $00, $00, $00, $08
  Data.b $08, $00, $00, $00, $00, $00, $00, $00, $00, $08
  Data.b $08, $00, $00, $00, $00, $00, $00, $00, $00, $08
ENTWICKLUNG:
  Data.l $08, $08, $08, $08, $08, $08, $08, $08, $08, $08
  Data.l $08, $08, $08, $08, $08, $08, $08, $08, $08, $08
  Data.l $08, $05, $00, $0a, $10, $10, $0a, $00, $05, $08
  Data.l $08, $05, $0a, $10, $14, $14, $10, $0a, $05, $08
  Data.l $08, $0a, $10, $14, $19, $19, $14, $10, $0a, $08
  Data.l $08, $10, $14, $19, $1e, $1e, $19, $14, $10, $08
  Data.l $08, $10, $14, $19, $1e, $1e, $19, $14, $10, $08
  Data.l $08, $0a, $10, $14, $19, $19, $14, $10, $0a, $08
  Data.l $08, $05, $0a, $10, $14, $14, $10, $0a, $05, $08
  Data.l $08, $05, $00, $0a, $10, $10, $0a, $00, $05, $08
WBAUER:
  Data.l $08, $08, $08, $08, $08, $08, $08, $08, $08, $08
  Data.l $08, $08, $08, $08, $08, $08, $08, $08, $08, $08
  Data.l $08, $00, $00, $00, $00, $00, $00, $00, $00, $08 
  Data.l $08, $19, $1e, $23, $28, $28, $23, $1e, $19, $08
  Data.l $08, $0a, $0f, $14, $19, $19, $14, $0f, $0a, $08
  Data.l $08, $04, $0a, $0f, $14, $14, $0f, $0a, $04, $08
  Data.l $08, $03, $08, $0a, $0f, $0f, $0a, $08, $03, $08
  Data.l $08, $02, $06, $08, $05, $05, $08, $06, $02, $08
  Data.l $08, $01, $04, $06, $00, $00, $06, $04, $01, $08
SBAUER:
  Data.l $08, $08, $08, $08, $08, $08, $08, $08, $08, $08
  Data.l $08, $08, $08, $08, $08, $08, $08, $08, $08, $08
  Data.l $08, $00, $00, $00, $00, $00, $00, $00, $00, $08 
  Data.l $08, $01, $04, $06, $00, $00, $06, $04, $01, $08  
  Data.l $08, $02, $06, $08, $05, $05, $08, $06, $02, $08  
  Data.l $08, $03, $08, $0a, $0f, $0f, $0a, $08, $03, $08  
  Data.l $08, $04, $0a, $0f, $14, $14, $0f, $0a, $04, $08  
  Data.l $08, $0a, $0f, $14, $19, $19, $14, $0f, $0a, $08  
  Data.l $08, $19, $1e, $23, $28, $28, $23, $1e, $19, $08
;Images
LEERFELDER:
LD:                                    ;dunkles Leerfeld
  Data.b $89, $50, $4E, $47, $0D, $0A, $1A, $0A, $00, $00, $00, $0D, $49, $48, $44, $52
  Data.b $00, $00, $00, $26, $00, $00, $00, $26, $04, $03, $00, $00, $00, $5A, $13, $F4
  Data.b $9D, $00, $00, $00, $01, $73, $52, $47, $42, $00, $AE, $CE, $1C, $E9, $00, $00
  Data.b $00, $04, $67, $41, $4D, $41, $00, $00, $B1, $8F, $0B, $FC, $61, $05, $00, $00
  Data.b $00, $20, $63, $48, $52, $4D, $00, $00, $7A, $26, $00, $00, $80, $84, $00, $00
  Data.b $FA, $00, $00, $00, $80, $E8, $00, $00, $75, $30, $00, $00, $EA, $60, $00, $00
  Data.b $3A, $98, $00, $00, $17, $70, $9C, $BA, $51, $3C, $00, $00, $00, $30, $50, $4C
  Data.b $54, $45, $00, $00, $00, $00, $00, $A4, $40, $80, $80, $FC, $FC, $C0, $FC, $00
  Data.b $00, $C0, $C0, $C0, $D8, $D8, $D8, $A0, $A0, $A0, $50, $50, $50, $50, $50, $FC
  Data.b $24, $EC, $24, $C8, $C8, $C8, $FC, $00, $00, $40, $80, $80, $94, $94, $94, $FC
  Data.b $FC, $FC, $05, $90, $A0, $D6, $00, $00, $00, $13, $49, $44, $41, $54, $28, $CF
  Data.b $63, $50, $C2, $04, $0C, $A3, $62, $A3, $62, $C3, $5C, $0C, $00, $61, $BA, $5F
  Data.b $E5, $F6, $75, $75, $44, $00, $00, $00, $00, $49, $45, $4E, $44, $AE, $42, $60
  Data.b $82 
LH:                                    ;helles Leerfeld
  Data.b $89, $50, $4E, $47, $0D, $0A, $1A, $0A, $00, $00, $00, $0D, $49, $48, $44, $52
  Data.b $00, $00, $00, $26, $00, $00, $00, $26, $04, $03, $00, $00, $00, $5A, $13, $F4
  Data.b $9D, $00, $00, $00, $01, $73, $52, $47, $42, $00, $AE, $CE, $1C, $E9, $00, $00
  Data.b $00, $04, $67, $41, $4D, $41, $00, $00, $B1, $8F, $0B, $FC, $61, $05, $00, $00
  Data.b $00, $20, $63, $48, $52, $4D, $00, $00, $7A, $26, $00, $00, $80, $84, $00, $00
  Data.b $FA, $00, $00, $00, $80, $E8, $00, $00, $75, $30, $00, $00, $EA, $60, $00, $00
  Data.b $3A, $98, $00, $00, $17, $70, $9C, $BA, $51, $3C, $00, $00, $00, $30, $50, $4C
  Data.b $54, $45, $00, $00, $00, $00, $00, $A4, $20, $AC, $20, $FC, $FC, $C0, $FC, $00
  Data.b $00, $C0, $C0, $C0, $D8, $D8, $D8, $A0, $A0, $A0, $50, $50, $50, $50, $50, $FC
  Data.b $24, $EC, $24, $C8, $C8, $C8, $FC, $00, $00, $FC, $FC, $FC, $94, $94, $94, $FC
  Data.b $FC, $FC, $67, $27, $7F, $C8, $00, $00, $00, $13, $49, $44, $41, $54, $28, $CF
  Data.b $63, $B8, $8B, $09, $18, $46, $C5, $46, $C5, $86, $B9, $18, $00, $6B, $03, $6F
  Data.b $69, $F0, $B1, $71, $E9, $00, $00, $00, $00, $49, $45, $4E, $44, $AE, $42, $60
  Data.b $82 
FIGUREN:
WBD:                                   ;PNG weisser Bauer auf dunklem Feld
  Data.b $89, $50, $4E, $47, $0D, $0A, $1A, $0A, $00, $00, $00, $0D, $49, $48, $44, $52
  Data.b $00, $00, $00, $26, $00, $00, $00, $26, $04, $03, $00, $00, $00, $5A, $13, $F4
  Data.b $9D, $00, $00, $00, $01, $73, $52, $47, $42, $00, $AE, $CE, $1C, $E9, $00, $00
  Data.b $00, $04, $67, $41, $4D, $41, $00, $00, $B1, $8F, $0B, $FC, $61, $05, $00, $00
  Data.b $00, $20, $63, $48, $52, $4D, $00, $00, $7A, $26, $00, $00, $80, $84, $00, $00
  Data.b $FA, $00, $00, $00, $80, $E8, $00, $00, $75, $30, $00, $00, $EA, $60, $00, $00
  Data.b $3A, $98, $00, $00, $17, $70, $9C, $BA, $51, $3C, $00, $00, $00, $30, $50, $4C
  Data.b $54, $45, $00, $00, $00, $00, $00, $A4, $20, $AC, $20, $40, $80, $80, $FC, $00
  Data.b $00, $C0, $C0, $C0, $D8, $D8, $D8, $A0, $A0, $A0, $50, $50, $50, $50, $50, $FC
  Data.b $24, $EC, $24, $C8, $C8, $C8, $FC, $00, $00, $FC, $FC, $FC, $94, $94, $94, $FC
  Data.b $FC, $FC, $8C, $19, $28, $84, $00, $00, $00, $7F, $49, $44, $41, $54, $28, $CF
  Data.b $AD, $D2, $D1, $09, $C0, $20, $0C, $04, $D0, $03, $BF, $BB, $4B, $A0, $FB, $EF
  Data.b $E0, $02, $B7, $4B, $C5, $9A, $18, $35, $94, $0A, $E6, $C7, $F2, $E0, $BC, $20
  Data.b $C5, $BD, $0E, $4E, $98, $20, $CD, $26, $80, $A1, $1A, $2E, $66, $CC, $46, $F2
  Data.b $97, $05, $59, $01, $97, $8E, $12, $EE, $9F, $7A, $16, $9B, $B2, $52, $3B, $D2
  Data.b $60, $A5, $82, $56, $A2, $07, $D9, $97, $39, $61, $41, $47, $B4, $4B, $F4, $06
  Data.b $A8, $36, $64, $D1, $3A, $D0, $4D, $5E, $D2, $1B, $61, $AD, $B4, $66, $F4, $ED
  Data.b $6C, $43, $F8, $68, $0B, $57, $BB, $CC, $B2, $1A, $9C, $41, $8D, $1C, $2E, $DC
  Data.b $32, $3F, $1F, $B6, $F5, $4F, $BA, $79, $00, $84, $40, $DA, $F2, $15, $0B, $A5
  Data.b $E4, $00, $00, $00, $00, $49, $45, $4E, $44, $AE, $42, $60, $82 
WBH:                                   ;PNG weisser Bauer auf hellem Feld  
  Data.b $89, $50, $4E, $47, $0D, $0A, $1A, $0A, $00, $00, $00, $0D, $49, $48, $44, $52
  Data.b $00, $00, $00, $26, $00, $00, $00, $26, $04, $03, $00, $00, $00, $5A, $13, $F4
  Data.b $9D, $00, $00, $00, $01, $73, $52, $47, $42, $00, $AE, $CE, $1C, $E9, $00, $00
  Data.b $00, $04, $67, $41, $4D, $41, $00, $00, $B1, $8F, $0B, $FC, $61, $05, $00, $00
  Data.b $00, $20, $63, $48, $52, $4D, $00, $00, $7A, $26, $00, $00, $80, $84, $00, $00
  Data.b $FA, $00, $00, $00, $80, $E8, $00, $00, $75, $30, $00, $00, $EA, $60, $00, $00
  Data.b $3A, $98, $00, $00, $17, $70, $9C, $BA, $51, $3C, $00, $00, $00, $30, $50, $4C
  Data.b $54, $45, $00, $00, $00, $00, $00, $A4, $20, $AC, $20, $FC, $FC, $C0, $FC, $00
  Data.b $00, $C0, $C0, $C0, $D8, $D8, $D8, $A0, $A0, $A0, $50, $50, $50, $50, $50, $FC
  Data.b $24, $EC, $24, $C8, $C8, $C8, $FC, $00, $00, $FC, $FC, $FC, $94, $94, $94, $FC
  Data.b $FC, $FC, $67, $27, $7F, $C8, $00, $00, $00, $75, $49, $44, $41, $54, $28, $CF
  Data.b $AD, $92, $8B, $0D, $C0, $20, $08, $44, $6F, $01, $F7, $5F, $8B, $05, $D8, $A5
  Data.b $D6, $0A, $39, $10, $9B, $36, $91, $98, $80, $CF, $78, $87, $1F, $E8, $1A, $38
  Data.b $C1, $04, $2D, $33, $01, $1C, $1A, $EB, $40, $90, $59, $AA, $B7, $AC, $D8, $DB
  Data.b $C1, $E2, $D1, $0B, $2A, $67, $C6, $3D, $02, $1B, $5A, $B6, $19, $6E, $A1, $6E
  Data.b $12, $D2, $41, $56, $78, $54, $BD, $54, $77, $30, $CE, $80, $28, $1E, $93, $92
  Data.b $F8, $54, $84, $92, $F8, $5C, $04, $1B, $D1, $54, $88, $35, $63, $FE, $B2, $4F
  Data.b $C9, $BD, $7A, $EF, $1A, $FF, $C7, $6F, $C6, $F1, $C2, $72, $7C, $65, $17, $A6
  Data.b $DB, $16, $7E, $F2, $4A, $54, $03, $00, $00, $00, $00, $49, $45, $4E, $44, $AE
  Data.b $42, $60, $82 
WSD:                                   ;PNG weisser Springer auf dunklem Feld
  Data.b $89, $50, $4E, $47, $0D, $0A, $1A, $0A, $00, $00, $00, $0D, $49, $48, $44, $52
  Data.b $00, $00, $00, $26, $00, $00, $00, $26, $04, $03, $00, $00, $00, $5A, $13, $F4
  Data.b $9D, $00, $00, $00, $01, $73, $52, $47, $42, $00, $AE, $CE, $1C, $E9, $00, $00
  Data.b $00, $04, $67, $41, $4D, $41, $00, $00, $B1, $8F, $0B, $FC, $61, $05, $00, $00
  Data.b $00, $20, $63, $48, $52, $4D, $00, $00, $7A, $26, $00, $00, $80, $84, $00, $00
  Data.b $FA, $00, $00, $00, $80, $E8, $00, $00, $75, $30, $00, $00, $EA, $60, $00, $00
  Data.b $3A, $98, $00, $00, $17, $70, $9C, $BA, $51, $3C, $00, $00, $00, $30, $50, $4C
  Data.b $54, $45, $00, $00, $00, $00, $00, $A4, $20, $AC, $20, $40, $80, $80, $FC, $00
  Data.b $00, $C0, $C0, $C0, $D8, $D8, $D8, $A0, $A0, $A0, $50, $50, $50, $50, $50, $FC
  Data.b $24, $EC, $24, $C8, $C8, $C8, $FC, $00, $00, $FC, $FC, $FC, $94, $94, $94, $FC
  Data.b $FC, $FC, $8C, $19, $28, $84, $00, $00, $00, $A2, $49, $44, $41, $54, $28, $CF
  Data.b $9D, $D2, $C1, $0D, $C3, $30, $08, $05, $D0, $2F, $F9, $CC, $2E, $48, $DE, $7F
  Data.b $07, $16, $60, $97, $82, $81, $86, $D8, $51, $D5, $D6, $F1, $C1, $79, $01, $22
  Data.b $48, $30, $CF, $85, $9F, $8C, $D1, $9F, $96, $0D, $DB, $9B, $11, $6C, $6F, $F5
  Data.b $20, $D0, $C3, $D4, $AE, $B1, $D5, $53, $52, $14, $22, $48, $88, $54, $25, $31
  Data.b $CC, $C0, $57, $22, $A2, $9A, $16, $36, $43, $46, $AE, $40, $44, $B9, $8A, $94
  Data.b $B7, $91, $50, $4F, $46, $7B, $C5, $4A, $4E, $83, $36, $1B, $A7, $49, $58, $A6
  Data.b $46, $CD, $BB, $A1, $5B, $A4, $22, $2D, $A6, $6B, $CD, $DA, $11, $15, $EE, $C6
  Data.b $CB, $C6, $BC, $19, $E5, $A9, $99, $DD, $C0, $C3, $A0, $CD, $18, $F0, $0A, $D4
  Data.b $6D, $FA, $80, $8B, $BC, $91, $1C, $18, $A3, $35, $52, $DF, $88, $1E, $4C, $0F
  Data.b $E3, $27, $A3, $2F, $0D, $D7, $FA, $64, $FF, $FD, $BB, $2F, $2F, $0B, $05, $2F
  Data.b $6C, $B9, $6E, $9E, $00, $00, $00, $00, $49, $45, $4E, $44, $AE, $42, $60, $82
WSH:                                   ;PNG weisser Springer auf hellem Feld
  Data.b $89, $50, $4E, $47, $0D, $0A, $1A, $0A, $00, $00, $00, $0D, $49, $48, $44, $52
  Data.b $00, $00, $00, $26, $00, $00, $00, $26, $04, $03, $00, $00, $00, $5A, $13, $F4
  Data.b $9D, $00, $00, $00, $01, $73, $52, $47, $42, $00, $AE, $CE, $1C, $E9, $00, $00
  Data.b $00, $04, $67, $41, $4D, $41, $00, $00, $B1, $8F, $0B, $FC, $61, $05, $00, $00
  Data.b $00, $20, $63, $48, $52, $4D, $00, $00, $7A, $26, $00, $00, $80, $84, $00, $00
  Data.b $FA, $00, $00, $00, $80, $E8, $00, $00, $75, $30, $00, $00, $EA, $60, $00, $00
  Data.b $3A, $98, $00, $00, $17, $70, $9C, $BA, $51, $3C, $00, $00, $00, $30, $50, $4C
  Data.b $54, $45, $00, $00, $00, $00, $00, $A4, $20, $AC, $20, $40, $80, $80, $FC, $00
  Data.b $00, $C0, $C0, $C0, $D8, $D8, $D8, $A0, $A0, $A0, $50, $50, $50, $50, $50, $FC
  Data.b $24, $EC, $24, $C8, $C8, $C8, $FC, $00, $00, $FC, $FC, $FC, $94, $94, $94, $FC
  Data.b $FC, $FC, $8C, $19, $28, $84, $00, $00, $00, $99, $49, $44, $41, $54, $28, $CF
  Data.b $95, $D0, $81, $0D, $C4, $20, $08, $05, $D0, $BF, $C0, $DF, $7F, $2D, $16, $60
  Data.b $97, $62, $01, $0B, $78, $B9, $B4, $D6, $A4, $ED, $53, $40, $81, $9E, $03, $9F
  Data.b $4C, $50, $57, $D3, $68, $73, $18, $61, $73, $E4, $83, $45, $1F, $B6, $1E, $CE
  Data.b $1A, $54, $24, $C2, $49, $C8, $BB, $52, $B1, $D8, $10, $88, $76, $70, $41, $B1
  Data.b $9D, $8A, $61, $02, $C9, $9D, $B2, $8D, $99, $D0, $83, $51, $4A, $64, $2E, $68
  Data.b $EF, $CD, $4A, $38, $4D, $DC, $22, $D4, $5F, $DD, $50, $CD, $43, $E3, $B6, $D1
  Data.b $5D, $BB, $AC, $7D, $22, $B7, $AF, $29, $B7, $51, $9B, $C5, $D1, $51, $CC, $7E
  Data.b $3C, $5A, $8B, $59, $2E, $EC, $DE, $65, $D1, $55, $F2, $69, $3C, $B3, $57, $82
  Data.b $72, $11, $68, $39, $F0, $30, $3D, $4C, $7E, $19, $5F, $1A, $9E, $F1, $CF, $FA
  Data.b $78, $6B, $17, $57, $83, $FA, $CF, $C7, $DE, $22, $5F, $00, $00, $00, $00, $49
  Data.b $45, $4E, $44, $AE, $42, $60, $82 
WLD:                                   ;PNG weisser Lufer auf dunklem Feld
  Data.b $89, $50, $4E, $47, $0D, $0A, $1A, $0A, $00, $00, $00, $0D, $49, $48, $44, $52
  Data.b $00, $00, $00, $26, $00, $00, $00, $26, $04, $03, $00, $00, $00, $5A, $13, $F4
  Data.b $9D, $00, $00, $00, $01, $73, $52, $47, $42, $00, $AE, $CE, $1C, $E9, $00, $00
  Data.b $00, $04, $67, $41, $4D, $41, $00, $00, $B1, $8F, $0B, $FC, $61, $05, $00, $00
  Data.b $00, $20, $63, $48, $52, $4D, $00, $00, $7A, $26, $00, $00, $80, $84, $00, $00
  Data.b $FA, $00, $00, $00, $80, $E8, $00, $00, $75, $30, $00, $00, $EA, $60, $00, $00
  Data.b $3A, $98, $00, $00, $17, $70, $9C, $BA, $51, $3C, $00, $00, $00, $30, $50, $4C
  Data.b $54, $45, $00, $00, $00, $00, $00, $A4, $20, $AC, $20, $40, $80, $80, $FC, $00
  Data.b $00, $C0, $C0, $C0, $D8, $D8, $D8, $A0, $A0, $A0, $50, $50, $50, $50, $50, $FC
  Data.b $24, $EC, $24, $C8, $C8, $C8, $FC, $00, $00, $FC, $FC, $FC, $94, $94, $94, $FC
  Data.b $FC, $FC, $8C, $19, $28, $84, $00, $00, $00, $8D, $49, $44, $41, $54, $28, $CF
  Data.b $95, $92, $41, $0E, $80, $30, $08, $04, $27, $F1, $EC, $5F, $4C, $FC, $FF, $1F
  Data.b $FA, $01, $FE, $22, $45, $4A, $30, $25, $56, $39, $F4, $30, $D9, $5D, $A0, $2D
  Data.b $E7, $5C, $FC, $65, $07, $DB, $C4, $80, $99, $09, $9F, $74, $1F, $F3, $D0, $3C
  Data.b $9E, $EC, $40, $44, $86, $DB, $19, $BB, $B2, $46, $66, $26, $0B, $A1, $33, $95
  Data.b $29, $6E, $99, $E1, $8C, $CC, $14, $D1, $8F, $15, $2B, $BC, $55, $8F, $6A, $96
  Data.b $6A, $66, $15, $F6, $DA, $D6, $CC, $BC, $6B, $C6, $5D, $CF, $7B, $21, $05, $BE
  Data.b $E5, $15, $7D, $FB, $26, $F1, $70, $8C, $FC, $5D, $D7, $F0, $3E, $8C, $7C, $E9
  Data.b $0F, $77, $07, $30, $F6, $6F, $B6, $B2, $DD, $43, $78, $A3, $2C, $CF, $CD, $67
  Data.b $8C, $F8, $FB, $9F, $A6, $BA, $00, $4E, $E8, $A4, $6D, $5A, $AF, $FC, $B5, $00
  Data.b $00, $00, $00, $49, $45, $4E, $44, $AE, $42, $60, $82 
WLH:                                   ;PNG weisser Lufer auf hellem Feld
  Data.b $89, $50, $4E, $47, $0D, $0A, $1A, $0A, $00, $00, $00, $0D, $49, $48, $44, $52
  Data.b $00, $00, $00, $26, $00, $00, $00, $26, $04, $03, $00, $00, $00, $5A, $13, $F4
  Data.b $9D, $00, $00, $00, $01, $73, $52, $47, $42, $00, $AE, $CE, $1C, $E9, $00, $00
  Data.b $00, $04, $67, $41, $4D, $41, $00, $00, $B1, $8F, $0B, $FC, $61, $05, $00, $00
  Data.b $00, $20, $63, $48, $52, $4D, $00, $00, $7A, $26, $00, $00, $80, $84, $00, $00
  Data.b $FA, $00, $00, $00, $80, $E8, $00, $00, $75, $30, $00, $00, $EA, $60, $00, $00
  Data.b $3A, $98, $00, $00, $17, $70, $9C, $BA, $51, $3C, $00, $00, $00, $30, $50, $4C
  Data.b $54, $45, $00, $00, $00, $00, $00, $A4, $20, $AC, $20, $40, $80, $80, $FC, $00
  Data.b $00, $C0, $C0, $C0, $D8, $D8, $D8, $A0, $A0, $A0, $50, $50, $50, $50, $50, $FC
  Data.b $24, $EC, $24, $C8, $C8, $C8, $FC, $00, $00, $FC, $FC, $FC, $94, $94, $94, $FC
  Data.b $FC, $FC, $8C, $19, $28, $84, $00, $00, $00, $7E, $49, $44, $41, $54, $28, $CF
  Data.b $95, $92, $C9, $11, $00, $21, $08, $04, $3B, $01, $F2, $4F, $CB, $04, $CC, $65
  Data.b $D5, $05, $C5, $92, $F2, $E0, $05, $AD, $0C, $E3, $41, $5E, $83, $57, $96, $90
  Data.b $85, $01, $2B, $CB, $5C, $ED, $BB, $D4, $2B, $A4, $43, $AC, $B3, $E6, $32, $B1
  Data.b $56, $26, $3C, $D3, $4A, $37, $2A, $93, $96, $25, $CF, $50, $86, $67, $EA, $E5
  Data.b $C8, $82, $DE, $68, $46, $E4, $25, $F2, $5C, $CA, $1A, $72, $66, $92, $FB, $88
  Data.b $1D, $E3, $8F, $F9, $5E, $70, $82, $3B, $BD, $60, $6E, $F5, $DB, $1F, $0E, $D3
  Data.b $17, $13, $AD, $CC, $52, $FA, $22, $76, $4A, $7B, $F3, $C6, $CC, $1B, $8C, $DE
  Data.b $D1, $6C, $B3, $9F, $FF, $A9, $8B, $0F, $93, $BE, $E5, $3A, $3D, $46, $D6, $6E
  Data.b $00, $00, $00, $00, $49, $45, $4E, $44, $AE, $42, $60, $82 
WTD:                                   ;PNG weisser Turm auf dunklem Feld
  Data.b $89, $50, $4E, $47, $0D, $0A, $1A, $0A, $00, $00, $00, $0D, $49, $48, $44, $52
  Data.b $00, $00, $00, $26, $00, $00, $00, $26, $04, $03, $00, $00, $00, $5A, $13, $F4
  Data.b $9D, $00, $00, $00, $01, $73, $52, $47, $42, $00, $AE, $CE, $1C, $E9, $00, $00
  Data.b $00, $04, $67, $41, $4D, $41, $00, $00, $B1, $8F, $0B, $FC, $61, $05, $00, $00
  Data.b $00, $20, $63, $48, $52, $4D, $00, $00, $7A, $26, $00, $00, $80, $84, $00, $00
  Data.b $FA, $00, $00, $00, $80, $E8, $00, $00, $75, $30, $00, $00, $EA, $60, $00, $00
  Data.b $3A, $98, $00, $00, $17, $70, $9C, $BA, $51, $3C, $00, $00, $00, $30, $50, $4C
  Data.b $54, $45, $00, $00, $00, $00, $00, $A4, $20, $AC, $20, $40, $80, $80, $FC, $00
  Data.b $00, $C0, $C0, $C0, $D8, $D8, $D8, $A0, $A0, $A0, $50, $50, $50, $50, $50, $FC
  Data.b $24, $EC, $24, $C8, $C8, $C8, $FC, $00, $00, $FC, $FC, $FC, $94, $94, $94, $FC
  Data.b $FC, $FC, $8C, $19, $28, $84, $00, $00, $00, $67, $49, $44, $41, $54, $28, $CF
  Data.b $63, $30, $C6, $04, $0C, $24, $88, $19, $30, $30, $30, $1B, $33, $30, $30, $40
  Data.b $18, $78, $C4, $78, $2F, $00, $45, $EE, $02, $31, $EF, $05, $FC, $62, $77, $61
  Data.b $E0, $02, $92, $79, $70, $80, $4F, $0C, $A1, $19, $AC, $15, $2A, $86, $A2, $0C
  Data.b $EA, $0F, $B8, $18, $92, $DF, $A0, $9A, $21, $5A, $87, $B0, $18, $16, $BF, $61
  Data.b $0B, $03, $6C, $61, $85, $14, $A6, $48, $F1, $8B, $19, $F6, $D8, $E2, $08, $53
  Data.b $0C, $59, $2B, $58, $33, $2E, $31, $84, $56, $88, $66, $12, $F4, $92, $9D, $76
  Data.b $01, $E0, $F5, $B8, $8C, $F2, $75, $17, $06, $00, $00, $00, $00, $49, $45, $4E
  Data.b $44, $AE, $42, $60, $82
WTH:                                   ;PNG weisser Turm auf hellem Feld  
  Data.b $89, $50, $4E, $47, $0D, $0A, $1A, $0A, $00, $00, $00, $0D, $49, $48, $44, $52
  Data.b $00, $00, $00, $26, $00, $00, $00, $26, $04, $03, $00, $00, $00, $5A, $13, $F4
  Data.b $9D, $00, $00, $00, $01, $73, $52, $47, $42, $00, $AE, $CE, $1C, $E9, $00, $00
  Data.b $00, $04, $67, $41, $4D, $41, $00, $00, $B1, $8F, $0B, $FC, $61, $05, $00, $00
  Data.b $00, $20, $63, $48, $52, $4D, $00, $00, $7A, $26, $00, $00, $80, $84, $00, $00
  Data.b $FA, $00, $00, $00, $80, $E8, $00, $00, $75, $30, $00, $00, $EA, $60, $00, $00
  Data.b $3A, $98, $00, $00, $17, $70, $9C, $BA, $51, $3C, $00, $00, $00, $30, $50, $4C
  Data.b $54, $45, $00, $00, $00, $00, $00, $A4, $20, $AC, $20, $40, $80, $80, $FC, $00
  Data.b $00, $C0, $C0, $C0, $D8, $D8, $D8, $A0, $A0, $A0, $50, $50, $50, $50, $50, $FC
  Data.b $24, $EC, $24, $C8, $C8, $C8, $FC, $00, $00, $FC, $FC, $FC, $94, $94, $94, $FC
  Data.b $FC, $FC, $8C, $19, $28, $84, $00, $00, $00, $66, $49, $44, $41, $54, $28, $CF
  Data.b $D5, $92, $D1, $0D, $C0, $20, $08, $44, $6F, $01, $F6, $5F, $8B, $05, $DC, $45
  Data.b $5B, $08, $D2, $70, $25, $F5, $B3, $24, $46, $78, $F1, $48, $38, $C4, $A8, $81
  Data.b $03, $A6, $80, $0C, $00, $96, $34, $4C, $F4, $22, $EB, $88, $F6, $2C, $DA, $6B
  Data.b $EA, $17, $D1, $B1, $2D, $B6, $C4, $D8, $E3, $99, $CF, $11, $2C, $CD, $E6, $62
  Data.b $BF, $FE, $CB, $C8, $6C, $CC, $03, $E6, $55, $F2, $34, $ED, $B7, $7A, $CF, $76
  Data.b $54, $59, $96, $DE, $E2, $37, $B6, $A5, $56, $1C, $68, $E9, $9F, $FC, $C2, $26
  Data.b $D7, $29, $BA, $ED, $AA, $A2, $F3, $7E, $00, $00, $00, $00, $49, $45, $4E, $44
  Data.b $AE, $42, $60, $82 
WDD:                                   ;PNG weisse Dame auf dunklem Feld
  Data.b $89, $50, $4E, $47, $0D, $0A, $1A, $0A, $00, $00, $00, $0D, $49, $48, $44, $52
  Data.b $00, $00, $00, $26, $00, $00, $00, $26, $04, $03, $00, $00, $00, $5A, $13, $F4
  Data.b $9D, $00, $00, $00, $01, $73, $52, $47, $42, $00, $AE, $CE, $1C, $E9, $00, $00
  Data.b $00, $04, $67, $41, $4D, $41, $00, $00, $B1, $8F, $0B, $FC, $61, $05, $00, $00
  Data.b $00, $20, $63, $48, $52, $4D, $00, $00, $7A, $26, $00, $00, $80, $84, $00, $00
  Data.b $FA, $00, $00, $00, $80, $E8, $00, $00, $75, $30, $00, $00, $EA, $60, $00, $00
  Data.b $3A, $98, $00, $00, $17, $70, $9C, $BA, $51, $3C, $00, $00, $00, $30, $50, $4C
  Data.b $54, $45, $00, $00, $00, $00, $00, $A4, $20, $AC, $20, $40, $80, $80, $FC, $00
  Data.b $00, $C0, $C0, $C0, $D8, $D8, $D8, $A0, $A0, $A0, $50, $50, $50, $50, $50, $FC
  Data.b $24, $EC, $24, $C8, $C8, $C8, $FC, $00, $00, $FC, $FC, $FC, $94, $94, $94, $FC
  Data.b $FC, $FC, $8C, $19, $28, $84, $00, $00, $00, $B0, $49, $44, $41, $54, $28, $CF
  Data.b $9D, $92, $D1, $0D, $C4, $20, $0C, $43, $2D, $E5, $9B, $5D, $22, $65, $FF, $1D
  Data.b $58, $80, $5D, $2E, $4E, $20, $70, $BA, $6B, $A5, $36, $6A, $95, $F2, $B0, $0D
  Data.b $A5, $85, $FD, $16, $9E, $32, $85, $7C, $33, $C0, $2F, $DE, $9B, $29, $20, $18
  Data.b $60, $4B, $E6, $26, $6D, $5D, $5C, $C7, $C6, $88, $30, $51, $C0, $29, $CA, $19
  Data.b $61, $6E, $62, $50, $08, $E6, $28, $C3, $25, $98, $CE, $51, $0A, $8A, $65, $9E
  Data.b $A5, $49, $57, $B3, $CD, $2A, $F6, $9A, $71, $30, $F7, $1C, $AF, $72, $C3, $7A
  Data.b $B0, $76, $30, $29, $A6, $27, $83, $33, $6C, $E6, $DD, $41, $1B, $9D, $98, $27
  Data.b $43, $D6, $42, $14, $33, $1E, $32, $59, $9F, $C0, $DD, $8B, $F1, $79, $B0, $7A
  Data.b $79, $7D, $91, $B1, $2A, $4E, $1F, $71, $F4, $A1, $A0, $3A, $0E, $3F, $D9, $AE
  Data.b $C5, $EC, $C8, $AB, $EF, $76, $78, $ED, $B9, $AE, $CA, $F6, $BA, $E5, $95, $1B
  Data.b $F6, $CF, $5B, $DB, $96, $97, $FF, $E9, $51, $1F, $84, $2E, $87, $8A, $02, $31
  Data.b $A3, $91, $00, $00, $00, $00, $49, $45, $4E, $44, $AE, $42, $60, $82 
WDH:                                   ;PNG weisse Dame auf hellem Feld
  Data.b $89, $50, $4E, $47, $0D, $0A, $1A, $0A, $00, $00, $00, $0D, $49, $48, $44, $52
  Data.b $00, $00, $00, $26, $00, $00, $00, $26, $04, $03, $00, $00, $00, $5A, $13, $F4
  Data.b $9D, $00, $00, $00, $01, $73, $52, $47, $42, $00, $AE, $CE, $1C, $E9, $00, $00
  Data.b $00, $04, $67, $41, $4D, $41, $00, $00, $B1, $8F, $0B, $FC, $61, $05, $00, $00
  Data.b $00, $20, $63, $48, $52, $4D, $00, $00, $7A, $26, $00, $00, $80, $84, $00, $00
  Data.b $FA, $00, $00, $00, $80, $E8, $00, $00, $75, $30, $00, $00, $EA, $60, $00, $00
  Data.b $3A, $98, $00, $00, $17, $70, $9C, $BA, $51, $3C, $00, $00, $00, $30, $50, $4C
  Data.b $54, $45, $00, $00, $00, $00, $00, $A4, $20, $AC, $20, $40, $80, $80, $FC, $00
  Data.b $00, $C0, $C0, $C0, $D8, $D8, $D8, $A0, $A0, $A0, $50, $50, $50, $50, $50, $FC
  Data.b $24, $EC, $24, $C8, $C8, $C8, $FC, $00, $00, $FC, $FC, $FC, $94, $94, $94, $FC
  Data.b $FC, $FC, $8C, $19, $28, $84, $00, $00, $00, $A2, $49, $44, $41, $54, $28, $CF
  Data.b $9D, $92, $8B, $11, $84, $30, $08, $44, $69, $60, $FB, $6F, $8B, $06, $E8, $45
  Data.b $96, $5F, $70, $EE, $CE, $19, $8F, $98, $C4, $BC, $EC, $A2, $41, $C5, $3E, $43
  Data.b $DE, $32, $15, $DC, $99, $88, $5F, $EC, $87, $A9, $08, $9C, $70, $4A, $E6, $26
  Data.b $F5, $E6, $3A, $4E, $4C, $11, $26, $0A, $B8, $45, $39, $53, $64, $0B, $B9, $AD
  Data.b $B5, $77, $04, $D3, $5A, $A5, $60, $58, $E6, $B3, $34, $69, $4F, $76, $D8, $A4
  Data.b $FD, $CD, $B8, $A8, $77, $8E, $A3, $3C, $30, $45, $0F, $CD, $30, $4C, $37, $AB
  Data.b $04, $CD, $74, $4E, $C2, $53, $20, $19, $B2, $7C, $31, $6A, $33, $2D, $C0, $F2
  Data.b $60, $BC, $A8, $FA, $B7, $B7, $4B, $6E, $7D, $2B, $B1, $1D, $0A, $C9, $02, $35
  Data.b $3B, $D1, $CC, $56, $BE, $F9, $6E, $CB, $6B, $EF, $75, $13, $76, $9E, $3B, $5E
  Data.b $3C, $B0, $6F, $DE, $79, $6D, $FC, $F9, $9F, $AE, $B8, $00, $A8, $66, $79, $51
  Data.b $13, $77, $50, $58, $00, $00, $00, $00, $49, $45, $4E, $44, $AE, $42, $60, $82
WKD:                                   ;PNG weisser Knig auf dunklem Feld
  Data.b $89, $50, $4E, $47, $0D, $0A, $1A, $0A, $00, $00, $00, $0D, $49, $48, $44, $52
  Data.b $00, $00, $00, $26, $00, $00, $00, $26, $04, $03, $00, $00, $00, $5A, $13, $F4
  Data.b $9D, $00, $00, $00, $01, $73, $52, $47, $42, $00, $AE, $CE, $1C, $E9, $00, $00
  Data.b $00, $04, $67, $41, $4D, $41, $00, $00, $B1, $8F, $0B, $FC, $61, $05, $00, $00
  Data.b $00, $20, $63, $48, $52, $4D, $00, $00, $7A, $26, $00, $00, $80, $84, $00, $00
  Data.b $FA, $00, $00, $00, $80, $E8, $00, $00, $75, $30, $00, $00, $EA, $60, $00, $00
  Data.b $3A, $98, $00, $00, $17, $70, $9C, $BA, $51, $3C, $00, $00, $00, $30, $50, $4C
  Data.b $54, $45, $00, $00, $00, $00, $00, $A4, $20, $AC, $20, $40, $80, $80, $FC, $00
  Data.b $00, $C0, $C0, $C0, $D8, $D8, $D8, $A0, $A0, $A0, $50, $50, $50, $50, $50, $FC
  Data.b $24, $EC, $24, $C8, $C8, $C8, $FC, $00, $00, $FC, $FC, $FC, $94, $94, $94, $FC
  Data.b $FC, $FC, $8C, $19, $28, $84, $00, $00, $00, $A3, $49, $44, $41, $54, $28, $CF
  Data.b $9D, $92, $5B, $0E, $C5, $20, $08, $44, $27, $E1, $DB, $BD, $90, $B8, $FF, $3D
  Data.b $B8, $01, $F6, $52, $40, $47, $4C, $6E, $72, $FB, $20, $AD, $99, $1E, $1C, $7C
  Data.b $50, $F4, $DF, $C0, $6B, $F6, $50, $29, $E4, $11, $FB, $58, $2F, $3F, $01, $30
  Data.b $91, $02, $10, $85, $C5, $80, $4C, $FB, $D3, $6C, $40, $7D, $90, $54, $C1, $7C
  Data.b $86, $B9, $6C, $F9, $9A, $CF, $0E, $16, $CA, $92, $85, $18, $C1, $32, $1B, $80
  Data.b $22, $98, $65, $78, $F9, $25, $8A, $CD, $6A, $64, $D4, $CC, $ED, $35, $8A, $09
  Data.b $F7, $52, $2C, $F7, $42, $33, $68, $9D, $67, $6B, $9B, $8D, $75, $B6, $70, $63
  Data.b $86, $F1, $0E, $F2, $4E, $18, $BD, $98, $71, $E3, $C5, $8C, $71, $B0, $B1, $9C
  Data.b $ED, $CE, $BB, $D7, $ED, $FF, $D6, $D5, $65, $C6, $EC, $DD, $EC, $E5, $66, $47
  Data.b $7F, $75, $39, $E5, $EC, $B9, $1E, $E8, $C3, $7F, $5A, $71, $01, $A9, $BD, $D8
  Data.b $28, $44, $C7, $53, $B5, $00, $00, $00, $00, $49, $45, $4E, $44, $AE, $42, $60
  Data.b $82 
WKH:                                   ;PNG weisser Knig auf hellem Feld
  Data.b $89, $50, $4E, $47, $0D, $0A, $1A, $0A, $00, $00, $00, $0D, $49, $48, $44, $52
  Data.b $00, $00, $00, $26, $00, $00, $00, $26, $04, $03, $00, $00, $00, $5A, $13, $F4
  Data.b $9D, $00, $00, $00, $01, $73, $52, $47, $42, $00, $AE, $CE, $1C, $E9, $00, $00
  Data.b $00, $04, $67, $41, $4D, $41, $00, $00, $B1, $8F, $0B, $FC, $61, $05, $00, $00
  Data.b $00, $20, $63, $48, $52, $4D, $00, $00, $7A, $26, $00, $00, $80, $84, $00, $00
  Data.b $FA, $00, $00, $00, $80, $E8, $00, $00, $75, $30, $00, $00, $EA, $60, $00, $00
  Data.b $3A, $98, $00, $00, $17, $70, $9C, $BA, $51, $3C, $00, $00, $00, $30, $50, $4C
  Data.b $54, $45, $00, $00, $00, $00, $00, $A4, $20, $AC, $20, $40, $80, $80, $FC, $00
  Data.b $00, $C0, $C0, $C0, $D8, $D8, $D8, $A0, $A0, $A0, $50, $50, $50, $50, $50, $FC
  Data.b $24, $EC, $24, $C8, $C8, $C8, $FC, $00, $00, $FC, $FC, $FC, $94, $94, $94, $FC
  Data.b $FC, $FC, $8C, $19, $28, $84, $00, $00, $00, $96, $49, $44, $41, $54, $28, $CF
  Data.b $9D, $92, $8B, $0D, $84, $30, $0C, $43, $BD, $40, $F6, $5F, $2B, $0B, $78, $17
  Data.b $9A, $7F, $2B, $A4, $3B, $A0, $42, $25, $7D, $C1, $89, $1B, $01, $DE, $17, $5E
  Data.b $B3, $87, $91, $42, $1E, $B1, $8F, $F5, $FC, $08, $A0, $12, $1E, $00, $A2, $A0
  Data.b $6D, $F0, $F4, $7A, $64, $61, $5D, $9B, $78, $64, $4C, $4B, $9E, $42, $31, $E6
  Data.b $B5, $F3, $13, $DA, $D1, $CA, $44, $DB, $2D, $28, $37, $DE, $37, $9C, $34, $6B
  Data.b $7F, $68, $2D, $27, $D7, $3D, $86, $49, $79, $19, $E6, $5E, $4A, $8C, $92, $B2
  Data.b $2F, $19, $4C, $F3, $6E, $5E, $36, $16, $6B, $06, $2C, $82, $F4, $98, $AC, $26
  Data.b $B7, $B1, $73, $C4, $B1, $69, $2A, $E5, $9F, $B6, $FB, $F2, $57, $5F, $4D, $31
  Data.b $36, $F7, $C4, $F9, $CA, $5B, $66, $DF, $73, $6A, $83, $3E, $FC, $A7, $B3, $2E
  Data.b $95, $E2, $DF, $2F, $75, $4D, $CE, $08, $00, $00, $00, $00, $49, $45, $4E, $44
  Data.b $AE, $42, $60, $82 
SBD:                                   ;PNG schwarzer Bauer auf dunklem Feld
  Data.b $89, $50, $4E, $47, $0D, $0A, $1A, $0A, $00, $00, $00, $0D, $49, $48, $44, $52
  Data.b $00, $00, $00, $26, $00, $00, $00, $26, $04, $03, $00, $00, $00, $5A, $13, $F4
  Data.b $9D, $00, $00, $00, $01, $73, $52, $47, $42, $00, $AE, $CE, $1C, $E9, $00, $00
  Data.b $00, $04, $67, $41, $4D, $41, $00, $00, $B1, $8F, $0B, $FC, $61, $05, $00, $00
  Data.b $00, $20, $63, $48, $52, $4D, $00, $00, $7A, $26, $00, $00, $80, $84, $00, $00
  Data.b $FA, $00, $00, $00, $80, $E8, $00, $00, $75, $30, $00, $00, $EA, $60, $00, $00
  Data.b $3A, $98, $00, $00, $17, $70, $9C, $BA, $51, $3C, $00, $00, $00, $30, $50, $4C
  Data.b $54, $45, $00, $00, $00, $00, $00, $A4, $20, $AC, $20, $40, $80, $80, $FC, $00
  Data.b $00, $C0, $C0, $C0, $D8, $D8, $D8, $A0, $A0, $A0, $50, $50, $50, $50, $50, $FC
  Data.b $24, $EC, $24, $C8, $C8, $C8, $FC, $00, $00, $FC, $FC, $FC, $94, $94, $94, $FC
  Data.b $FC, $FC, $8C, $19, $28, $84, $00, $00, $00, $57, $49, $44, $41, $54, $28, $CF
  Data.b $BD, $D2, $41, $0A, $C0, $20, $0C, $44, $D1, $0F, $B9, $50, $C0, $FB, $DF, $AD
  Data.b $54, $51, $93, $1A, $15, $A1, $98, $E5, $63, $26, $66, $21, $69, $1C, $4E, $4D
  Data.b $91, $AF, $29, $34, $AC, $C6, $3B, $3F, $5A, $F4, $46, $EA, $B1, $55, $57, $B3
  Data.b $89, $33, $30, $C1, $8B, $16, $DD, $12, $DD, $1C, $74, $C1, $22, $7D, $5B, $DB
  Data.b $88, $8B, $95, $E0, $CC, $D4, $98, $2C, $0C, $7C, $F9, $96, $1D, $FD, $C9, $8D
  Data.b $3D, $81, $C2, $5E, $A2, $96, $EC, $26, $89, $00, $00, $00, $00, $49, $45, $4E
  Data.b $44, $AE, $42, $60, $82
SBH:                                   ;PNG schwarzer Bauer auf hellem Feld
  Data.b $89, $50, $4E, $47, $0D, $0A, $1A, $0A, $00, $00, $00, $0D, $49, $48, $44, $52
  Data.b $00, $00, $00, $26, $00, $00, $00, $26, $04, $03, $00, $00, $00, $5A, $13, $F4
  Data.b $9D, $00, $00, $00, $01, $73, $52, $47, $42, $00, $AE, $CE, $1C, $E9, $00, $00
  Data.b $00, $04, $67, $41, $4D, $41, $00, $00, $B1, $8F, $0B, $FC, $61, $05, $00, $00
  Data.b $00, $20, $63, $48, $52, $4D, $00, $00, $7A, $26, $00, $00, $80, $84, $00, $00
  Data.b $FA, $00, $00, $00, $80, $E8, $00, $00, $75, $30, $00, $00, $EA, $60, $00, $00
  Data.b $3A, $98, $00, $00, $17, $70, $9C, $BA, $51, $3C, $00, $00, $00, $30, $50, $4C
  Data.b $54, $45, $00, $00, $00, $00, $00, $A4, $20, $AC, $20, $40, $80, $80, $FC, $00
  Data.b $00, $C0, $C0, $C0, $D8, $D8, $D8, $A0, $A0, $A0, $50, $50, $50, $50, $50, $FC
  Data.b $24, $EC, $24, $C8, $C8, $C8, $FC, $00, $00, $FC, $FC, $FC, $94, $94, $94, $FC
  Data.b $FC, $FC, $8C, $19, $28, $84, $00, $00, $00, $59, $49, $44, $41, $54, $28, $CF
  Data.b $BD, $D2, $C1, $0D, $00, $21, $08, $44, $D1, $DF, $00, $FD, $B7, $45, $03, $F6
  Data.b $B2, $59, $8D, $0A, $2B, $6A, $4C, $36, $72, $7C, $99, $41, $0E, $92, $C6, $E1
  Data.b $D4, $14, $F9, $9A, $42, $C3, $6A, $BC, $F3, $A3, $45, $6F, $A4, $1E, $5B, $75
  Data.b $35, $9B, $38, $03, $13, $BC, $68, $D1, $2D, $D1, $CD, $41, $17, $2C, $D2, $B7
  Data.b $B5, $8D, $B8, $58, $09, $CE, $4C, $8D, $C9, $C2, $C0, $97, $6F, $D9, $D1, $9F
  Data.b $DC, $D8, $03, $D3, $22, $9A, $1F, $2A, $34, $3F, $16, $00, $00, $00, $00, $49
  Data.b $45, $4E, $44, $AE, $42, $60, $82 
SSD:                                   ;PNG schwarzer Springer auf dunklem Feld
  Data.b $89, $50, $4E, $47, $0D, $0A, $1A, $0A, $00, $00, $00, $0D, $49, $48, $44, $52
  Data.b $00, $00, $00, $26, $00, $00, $00, $26, $04, $03, $00, $00, $00, $5A, $13, $F4
  Data.b $9D, $00, $00, $00, $01, $73, $52, $47, $42, $00, $AE, $CE, $1C, $E9, $00, $00
  Data.b $00, $04, $67, $41, $4D, $41, $00, $00, $B1, $8F, $0B, $FC, $61, $05, $00, $00
  Data.b $00, $20, $63, $48, $52, $4D, $00, $00, $7A, $26, $00, $00, $80, $84, $00, $00
  Data.b $FA, $00, $00, $00, $80, $E8, $00, $00, $75, $30, $00, $00, $EA, $60, $00, $00
  Data.b $3A, $98, $00, $00, $17, $70, $9C, $BA, $51, $3C, $00, $00, $00, $30, $50, $4C
  Data.b $54, $45, $00, $00, $00, $00, $00, $A4, $20, $AC, $20, $40, $80, $80, $FC, $00
  Data.b $00, $C0, $C0, $C0, $D8, $D8, $D8, $A0, $A0, $A0, $50, $50, $50, $50, $50, $FC
  Data.b $24, $EC, $24, $C8, $C8, $C8, $FC, $00, $00, $FC, $FC, $FC, $94, $94, $94, $FC
  Data.b $FC, $FC, $8C, $19, $28, $84, $00, $00, $00, $95, $49, $44, $41, $54, $28, $CF
  Data.b $AD, $D2, $41, $0E, $C4, $20, $08, $05, $D0, $9F, $B8, $F6, $2E, $24, $BD, $FF
  Data.b $1D, $BC, $80, $77, $19, $11, $F8, $25, $98, $69, $D2, $C9, $10, $36, $7D, $0A
  Data.b $A8, $29, $AE, $33, $F0, $CA, $04, $79, $35, $AC, $AD, $AC, $86, $95, $A5, $1F
  Data.b $34, $AA, $F5, $01, $16, $B3, $56, $A3, $25, $33, $5A, $5B, $5B, $35, $4C, $47
  Data.b $70, $82, $61, $B2, $E9, $B8, $37, $62, $97, $EA, $54, $6B, $99, $0C, $61, $A0
  Data.b $31, $66, $18, $B2, $B5, $D3, $86, $59, $2A, $B5, $21, $5F, $8C, $53, $63, $B0
  Data.b $A6, $1D, $58, $92, $09, $C6, $7E, $12, $B3, $E9, $66, $EF, $79, $1F, $70, $7F
  Data.b $F4, $D8, $46, $D3, $62, $0E, $77, $BB, $B4, $5B, $BE, $88, $3F, $98, $1C, $96
  Data.b $AE, $A7, $97, $AB, $D6, $69, $F2, $17, $03, $9E, $EC, $B7, $7F, $F7, $03, $18
  Data.b $99, $66, $F1, $48, $C5, $78, $47, $00, $00, $00, $00, $49, $45, $4E, $44, $AE
  Data.b $42, $60, $82
SSH:                                   ;PNG schwarzer Springer auf hellem Feld
  Data.b $89, $50, $4E, $47, $0D, $0A, $1A, $0A, $00, $00, $00, $0D, $49, $48, $44, $52
  Data.b $00, $00, $00, $26, $00, $00, $00, $26, $04, $03, $00, $00, $00, $5A, $13, $F4
  Data.b $9D, $00, $00, $00, $01, $73, $52, $47, $42, $00, $AE, $CE, $1C, $E9, $00, $00
  Data.b $00, $04, $67, $41, $4D, $41, $00, $00, $B1, $8F, $0B, $FC, $61, $05, $00, $00
  Data.b $00, $20, $63, $48, $52, $4D, $00, $00, $7A, $26, $00, $00, $80, $84, $00, $00
  Data.b $FA, $00, $00, $00, $80, $E8, $00, $00, $75, $30, $00, $00, $EA, $60, $00, $00
  Data.b $3A, $98, $00, $00, $17, $70, $9C, $BA, $51, $3C, $00, $00, $00, $30, $50, $4C
  Data.b $54, $45, $00, $00, $00, $00, $00, $A4, $20, $AC, $20, $40, $80, $80, $FC, $00
  Data.b $00, $C0, $C0, $C0, $D8, $D8, $D8, $A0, $A0, $A0, $50, $50, $50, $50, $50, $FC
  Data.b $24, $EC, $24, $C8, $C8, $C8, $FC, $00, $00, $FC, $FC, $FC, $94, $94, $94, $FC
  Data.b $FC, $FC, $8C, $19, $28, $84, $00, $00, $00, $8D, $49, $44, $41, $54, $28, $CF
  Data.b $AD, $D2, $6B, $0E, $03, $21, $08, $04, $E0, $B9, $00, $F7, $BF, $16, $17, $E0
  Data.b $2E, $55, $1E, $D3, $89, $66, $9B, $B4, $29, $E1, $8F, $DF, $0A, $A8, $59, $C4
  Data.b $1D, $F8, $CA, $1C, $FA, $75, $CC, $56, $9E, $86, $95, $47, $3F, $EC, $38, $6D
  Data.b $D5, $B2, $98, $B5, $3B, $4C, $AC, $88, $63, $C4, $10, $8D, $E0, $84, $42, $B1
  Data.b $E6, $C8, $8D, $98, $13, $77, $4B, $31, $8C, $81, $C6, $88, $31, $A8, $D9, $6D
  Data.b $5E, $26, $A5, $35, $E4, $C1, $38, $75, $06, $67, $E6, $D2, $C5, $3C, $57, $56
  Data.b $2D, $2C, $DA, $EA, $3D, $DF, $07, $CC, $85, $CD, $36, $DA, $2E, $E6, $F0, $B6
  Data.b $C8, $36, $72, $91, $7E, $30, $BF, $4C, $AE, $B7, $2F, $77, $9A, $D1, $FC, $2F
  Data.b $06, $7C, $B2, $DF, $FE, $DD, $17, $41, $11, $5C, $A0, $94, $41, $B8, $B6, $00
  Data.b $00, $00, $00, $49, $45, $4E, $44, $AE, $42, $60, $82 
SLD:                                   ;PNG schwarzer Lufer auf dunklem Feld
  Data.b $89, $50, $4E, $47, $0D, $0A, $1A, $0A, $00, $00, $00, $0D, $49, $48, $44, $52
  Data.b $00, $00, $00, $26, $00, $00, $00, $26, $04, $03, $00, $00, $00, $5A, $13, $F4
  Data.b $9D, $00, $00, $00, $01, $73, $52, $47, $42, $00, $AE, $CE, $1C, $E9, $00, $00
  Data.b $00, $04, $67, $41, $4D, $41, $00, $00, $B1, $8F, $0B, $FC, $61, $05, $00, $00
  Data.b $00, $20, $63, $48, $52, $4D, $00, $00, $7A, $26, $00, $00, $80, $84, $00, $00
  Data.b $FA, $00, $00, $00, $80, $E8, $00, $00, $75, $30, $00, $00, $EA, $60, $00, $00
  Data.b $3A, $98, $00, $00, $17, $70, $9C, $BA, $51, $3C, $00, $00, $00, $30, $50, $4C
  Data.b $54, $45, $00, $00, $00, $00, $00, $A4, $20, $AC, $20, $40, $80, $80, $FC, $00
  Data.b $00, $C0, $C0, $C0, $D8, $D8, $D8, $A0, $A0, $A0, $50, $50, $50, $50, $50, $FC
  Data.b $24, $EC, $24, $C8, $C8, $C8, $FC, $00, $00, $FC, $FC, $FC, $94, $94, $94, $FC
  Data.b $FC, $FC, $8C, $19, $28, $84, $00, $00, $00, $70, $49, $44, $41, $54, $28, $CF
  Data.b $9D, $92, $CB, $0D, $80, $30, $0C, $43, $9F, $D4, $33, $BB, $20, $75, $FF, $1D
  Data.b $58, $20, $BB, $F0, $11, $49, $5B, $6A, $89, $40, $8E, $4F, $B6, $E3, $7E, $A8
  Data.b $F3, $F0, $95, $AD, $94, $89, $01, $BF, $59, $32, $0F, $1A, $C4, $9D, $E7, $94
  Data.b $81, $41, $27, $A4, $93, $B9, $B0, $31, $7B, $30, $6E, $C6, $C8, $CC, $2C, $C5
  Data.b $26, $AF, $DA, $A1, $BA, $A8, $CE, $F2, $6C, $92, $2D, $47, $97, $ED, $5D, $97
  Data.b $BC, $97, $74, $DE, $05, $FD, $E1, $88, $7C, $62, $0F, $91, $4F, $EC, $D1, $4C
  Data.b $79, $5D, $58, $A3, $E2, $E7, $7F, $DA, $CD, $0E, $11, $3D, $6F, $C4, $F1, $FB
  Data.b $D2, $88, $00, $00, $00, $00, $49, $45, $4E, $44, $AE, $42, $60, $82 
SLH:                                   ;PNG schwarzer Lufer auf hellem Feld  
  Data.b $89, $50, $4E, $47, $0D, $0A, $1A, $0A, $00, $00, $00, $0D, $49, $48, $44, $52
  Data.b $00, $00, $00, $26, $00, $00, $00, $26, $04, $03, $00, $00, $00, $5A, $13, $F4
  Data.b $9D, $00, $00, $00, $01, $73, $52, $47, $42, $00, $AE, $CE, $1C, $E9, $00, $00
  Data.b $00, $04, $67, $41, $4D, $41, $00, $00, $B1, $8F, $0B, $FC, $61, $05, $00, $00
  Data.b $00, $20, $63, $48, $52, $4D, $00, $00, $7A, $26, $00, $00, $80, $84, $00, $00
  Data.b $FA, $00, $00, $00, $80, $E8, $00, $00, $75, $30, $00, $00, $EA, $60, $00, $00
  Data.b $3A, $98, $00, $00, $17, $70, $9C, $BA, $51, $3C, $00, $00, $00, $30, $50, $4C
  Data.b $54, $45, $00, $00, $00, $80, $00, $00, $00, $80, $00, $80, $80, $00, $00, $00
  Data.b $80, $80, $00, $80, $00, $80, $80, $80, $80, $80, $C0, $C0, $C0, $FF, $00, $00
  Data.b $00, $FF, $00, $FF, $FF, $00, $00, $00, $FF, $FF, $00, $FF, $00, $FF, $FF, $FF
  Data.b $FF, $FF, $7B, $1F, $B1, $C4, $00, $00, $00, $6A, $49, $44, $41, $54, $28, $CF
  Data.b $AD, $92, $41, $0E, $C0, $20, $08, $04, $E7, $07, $FE, $FF, $97, $FD, $01, $4D
  Data.b $9B, $82, $58, $36, $46, $9B, $72, $F0, $30, $59, $96, $45, $C5, $6A, $B1, $CB
  Data.b $0E, $5A, $61, $C0, $67, $B6, $E8, $07, $1D, $E2, $9D, $57, $B5, $81, $41, $12
  Data.b $92, $64, $2E, $EC, $CC, $5E, $8C, $87, $31, $B2, $14, $67, $CA, $4A, $AF, $9A
  Data.b $A1, $B2, $A8, $CC, $72, $37, $C9, $9A, $1F, $BF, $DC, $CB, $B2, $DF, $0D, $FD
  Data.b $E1, $08, $7F, $62, $0E, $E1, $4F, $CC, $D1, $4C, $F5, $BA, $D0, $22, $E2, $F6
  Data.b $3F, $4D, $75, $02, $4F, $2C, $F3, $1B, $B2, $65, $D3, $DE, $00, $00, $00, $00
  Data.b $49, $45, $4E, $44, $AE, $42, $60, $82
STD:                                   ;PNG schwarzer Turm auf dunklem Feld  
  Data.b $89, $50, $4E, $47, $0D, $0A, $1A, $0A, $00, $00, $00, $0D, $49, $48, $44, $52
  Data.b $00, $00, $00, $26, $00, $00, $00, $26, $04, $03, $00, $00, $00, $5A, $13, $F4
  Data.b $9D, $00, $00, $00, $01, $73, $52, $47, $42, $00, $AE, $CE, $1C, $E9, $00, $00
  Data.b $00, $04, $67, $41, $4D, $41, $00, $00, $B1, $8F, $0B, $FC, $61, $05, $00, $00
  Data.b $00, $20, $63, $48, $52, $4D, $00, $00, $7A, $26, $00, $00, $80, $84, $00, $00
  Data.b $FA, $00, $00, $00, $80, $E8, $00, $00, $75, $30, $00, $00, $EA, $60, $00, $00
  Data.b $3A, $98, $00, $00, $17, $70, $9C, $BA, $51, $3C, $00, $00, $00, $30, $50, $4C
  Data.b $54, $45, $00, $00, $00, $00, $00, $A4, $20, $AC, $20, $40, $80, $80, $FC, $00
  Data.b $00, $C0, $C0, $C0, $D8, $D8, $D8, $A0, $A0, $A0, $50, $50, $50, $50, $50, $FC
  Data.b $24, $EC, $24, $C8, $C8, $C8, $FC, $00, $00, $FC, $FC, $FC, $94, $94, $94, $FC
  Data.b $FC, $FC, $8C, $19, $28, $84, $00, $00, $00, $5A, $49, $44, $41, $54, $28, $CF
  Data.b $63, $30, $C6, $04, $0C, $24, $88, $19, $30, $30, $30, $1B, $33, $30, $30, $40
  Data.b $18, $78, $C5, $E0, $80, $64, $B1, $BB, $08, $80, $4F, $1D, $92, $20, $33, $DC
  Data.b $CD, $06, $BC, $50, $9D, $17, $10, $62, $C6, $70, $75, $48, $7E, $33, $40, $D6
  Data.b $3A, $84, $C5, $B0, $F8, $0D, $5B, $18, $60, $0B, $2B, $A4, $30, $45, $8A, $5F
  Data.b $72, $E3, $03, $59, $08, $2C, $C8, $80, $AA, $15, $AC, $19, $97, $3A, $22, $C5
  Data.b $C8, $4E, $BB, $00, $9A, $7E, $79, $87, $24, $B5, $01, $25, $00, $00, $00, $00
  Data.b $49, $45, $4E, $44, $AE, $42, $60, $82 
STH:                                   ;PNG schwarzer Turm auf hellem Feld    
  Data.b $89, $50, $4E, $47, $0D, $0A, $1A, $0A, $00, $00, $00, $0D, $49, $48, $44, $52
  Data.b $00, $00, $00, $26, $00, $00, $00, $26, $04, $03, $00, $00, $00, $5A, $13, $F4
  Data.b $9D, $00, $00, $00, $01, $73, $52, $47, $42, $00, $AE, $CE, $1C, $E9, $00, $00
  Data.b $00, $04, $67, $41, $4D, $41, $00, $00, $B1, $8F, $0B, $FC, $61, $05, $00, $00
  Data.b $00, $20, $63, $48, $52, $4D, $00, $00, $7A, $26, $00, $00, $80, $84, $00, $00
  Data.b $FA, $00, $00, $00, $80, $E8, $00, $00, $75, $30, $00, $00, $EA, $60, $00, $00
  Data.b $3A, $98, $00, $00, $17, $70, $9C, $BA, $51, $3C, $00, $00, $00, $30, $50, $4C
  Data.b $54, $45, $00, $00, $00, $00, $00, $A4, $20, $AC, $20, $40, $80, $80, $FC, $00
  Data.b $00, $C0, $C0, $C0, $D8, $D8, $D8, $A0, $A0, $A0, $50, $50, $50, $50, $50, $FC
  Data.b $24, $EC, $24, $C8, $C8, $C8, $FC, $00, $00, $FC, $FC, $FC, $94, $94, $94, $FC
  Data.b $FC, $FC, $8C, $19, $28, $84, $00, $00, $00, $5A, $49, $44, $41, $54, $28, $CF
  Data.b $D5, $92, $C1, $0D, $00, $20, $08, $03, $BB, $00, $FB, $AF, $C5, $02, $EC, $62
  Data.b $A2, $06, $6B, $44, $A2, $FE, $E4, $65, $2E, $6D, $80, $22, $6C, $2D, $5C, $30
  Data.b $05, $C4, $00, $B4, $47, $CA, $BC, $AE, $19, $F5, $CC, $74, $04, $C5, $67, $56
  Data.b $E9, $4E, $1D, $CC, $5C, $47, $BB, $29, $5B, $3F, $66, $C1, $6E, $51, $06, $51
  Data.b $56, $94, $29, $DD, $F7, $F5, $1E, $8C, $2A, $C4, $6C, $AD, $E6, $9D, $EE, $90
  Data.b $3D, $FF, $DD, $02, $90, $B2, $7B, $E8, $E3, $A1, $4C, $A0, $00, $00, $00, $00
  Data.b $49, $45, $4E, $44, $AE, $42, $60, $82 
SDD:                                   ;PNG schwarze Dame auf dunklem Feld
  Data.b $89, $50, $4E, $47, $0D, $0A, $1A, $0A, $00, $00, $00, $0D, $49, $48, $44, $52
  Data.b $00, $00, $00, $26, $00, $00, $00, $26, $04, $03, $00, $00, $00, $5A, $13, $F4
  Data.b $9D, $00, $00, $00, $01, $73, $52, $47, $42, $00, $AE, $CE, $1C, $E9, $00, $00
  Data.b $00, $04, $67, $41, $4D, $41, $00, $00, $B1, $8F, $0B, $FC, $61, $05, $00, $00
  Data.b $00, $20, $63, $48, $52, $4D, $00, $00, $7A, $26, $00, $00, $80, $84, $00, $00
  Data.b $FA, $00, $00, $00, $80, $E8, $00, $00, $75, $30, $00, $00, $EA, $60, $00, $00
  Data.b $3A, $98, $00, $00, $17, $70, $9C, $BA, $51, $3C, $00, $00, $00, $30, $50, $4C
  Data.b $54, $45, $00, $00, $00, $00, $00, $A4, $20, $AC, $20, $40, $80, $80, $FC, $00
  Data.b $00, $C0, $C0, $C0, $D8, $D8, $D8, $A0, $A0, $A0, $50, $50, $50, $50, $50, $FC
  Data.b $24, $EC, $24, $C8, $C8, $C8, $FC, $00, $00, $FC, $FC, $FC, $94, $94, $94, $FC
  Data.b $FC, $FC, $8C, $19, $28, $84, $00, $00, $00, $94, $49, $44, $41, $54, $28, $CF
  Data.b $A5, $92, $6B, $0A, $C4, $30, $08, $84, $07, $FC, $DD, $BB, $08, $DE, $FF, $0E
  Data.b $BD, $40, $EE, $D2, $F8, $88, $1A, $BA, $5B, $E8, $AE, $A4, $0D, $7E, $75, $06
  Data.b $63, $0A, $B9, $07, $DE, $32, $06, $ED, $0C, $98, $4B, $9F, $62, $0C, $D0, $64
  Data.b $BA, $39, $9B, $A2, $C6, $D4, $C2, $44, $91, $C4, $27, $49, $23, $2B, $88, $CC
  Data.b $DF, $64, $8C, $17, $B3, $82, $64, $EE, $27, $2E, $E2, $B5, $49, $B1, $B4, $FD
  Data.b $CE, $34, $89, $FE, $EC, $28, $AF, $18, $25, $E3, $CE, $22, $16, $63, $F4, $A0
  Data.b $BF, $99, $1E, $61, $78, $C0, $A6, $0F, $1B, $FD, $38, $AD, $E6, $18, $36, $7C
  Data.b $67, $9B, $D4, $EF, $A8, $31, $29, $96, $7E, $C5, $CA, $4F, $9E, $B5, $37, $C6
  Data.b $CD, $8F, $1E, $FA, $FB, $E8, $B7, $DA, $A6, $1F, $FF, $D3, $16, $17, $1F, $94
  Data.b $62, $6B, $CE, $ED, $B9, $76, $00, $00, $00, $00, $49, $45, $4E, $44, $AE, $42
  Data.b $60, $82
SDH:                                   ;PNG schwarze Dame auf hellem Feld
  Data.b $89, $50, $4E, $47, $0D, $0A, $1A, $0A, $00, $00, $00, $0D, $49, $48, $44, $52
  Data.b $00, $00, $00, $26, $00, $00, $00, $26, $04, $03, $00, $00, $00, $5A, $13, $F4
  Data.b $9D, $00, $00, $00, $01, $73, $52, $47, $42, $00, $AE, $CE, $1C, $E9, $00, $00
  Data.b $00, $04, $67, $41, $4D, $41, $00, $00, $B1, $8F, $0B, $FC, $61, $05, $00, $00
  Data.b $00, $20, $63, $48, $52, $4D, $00, $00, $7A, $26, $00, $00, $80, $84, $00, $00
  Data.b $FA, $00, $00, $00, $80, $E8, $00, $00, $75, $30, $00, $00, $EA, $60, $00, $00
  Data.b $3A, $98, $00, $00, $17, $70, $9C, $BA, $51, $3C, $00, $00, $00, $30, $50, $4C
  Data.b $54, $45, $00, $00, $00, $00, $00, $A4, $20, $AC, $20, $40, $80, $80, $FC, $00
  Data.b $00, $C0, $C0, $C0, $D8, $D8, $D8, $A0, $A0, $A0, $50, $50, $50, $50, $50, $FC
  Data.b $24, $EC, $24, $C8, $C8, $C8, $FC, $00, $00, $FC, $FC, $FC, $94, $94, $94, $FC
  Data.b $FC, $FC, $8C, $19, $28, $84, $00, $00, $00, $8B, $49, $44, $41, $54, $28, $CF
  Data.b $A5, $92, $81, $0D, $80, $30, $08, $04, $7F, $01, $F6, $5F, $8B, $05, $D8, $C5
  Data.b $F6, $A1, $80, $A9, $9A, $A8, $44, $AD, $5C, $F9, $4F, $5B, $0A, $DB, $03, $6F
  Data.b $99, $42, $CE, $0C, $18, $CF, $7C, $8B, $29, $20, $83, $CD, $C1, $D9, $10, $35
  Data.b $36, $2D, $28, $8A, $24, $A6, $2C, $8D, $58, $10, $99, $7F, $85, $4C, $17, $63
  Data.b $41, $32, $F7, $33, $17, $E9, $1A, $AC, $58, $DA, $DE, $B3, $99, $C4, $FA, $B8
  Data.b $95, $57, $4C, $92, $69, $67, $11, $8B, $29, $7A, $C8, $6F, $C6, $2D, $44, $27
  Data.b $F8, $07, $1E, $7D, $D4, $F2, $80, $16, $3B, $49, $BD, $47, $8D, $59, $B1, $F4
  Data.b $2B, $56, $7E, $F6, $AC, $DD, $98, $36, $3F, $79, $58, $DF, $A5, $9F, $65, $DD
  Data.b $B7, $7B, $DA, $E2, $00, $43, $CC, $54, $32, $4B, $17, $98, $A5, $00, $00, $00
  Data.b $00, $49, $45, $4E, $44, $AE, $42, $60, $82 
SKD:                                   ;PNG schwarzer Knig auf dunklem Feld
  Data.b $89, $50, $4E, $47, $0D, $0A, $1A, $0A, $00, $00, $00, $0D, $49, $48, $44, $52
  Data.b $00, $00, $00, $26, $00, $00, $00, $26, $04, $03, $00, $00, $00, $5A, $13, $F4
  Data.b $9D, $00, $00, $00, $01, $73, $52, $47, $42, $00, $AE, $CE, $1C, $E9, $00, $00
  Data.b $00, $04, $67, $41, $4D, $41, $00, $00, $B1, $8F, $0B, $FC, $61, $05, $00, $00
  Data.b $00, $20, $63, $48, $52, $4D, $00, $00, $7A, $26, $00, $00, $80, $84, $00, $00
  Data.b $FA, $00, $00, $00, $80, $E8, $00, $00, $75, $30, $00, $00, $EA, $60, $00, $00
  Data.b $3A, $98, $00, $00, $17, $70, $9C, $BA, $51, $3C, $00, $00, $00, $30, $50, $4C
  Data.b $54, $45, $00, $00, $00, $00, $00, $A4, $20, $AC, $20, $40, $80, $80, $FC, $00
  Data.b $00, $C0, $C0, $C0, $D8, $D8, $D8, $A0, $A0, $A0, $50, $50, $50, $50, $50, $FC
  Data.b $24, $EC, $24, $C8, $C8, $C8, $FC, $00, $00, $FC, $FC, $FC, $94, $94, $94, $FC
  Data.b $FC, $FC, $8C, $19, $28, $84, $00, $00, $00, $A7, $49, $44, $41, $54, $28, $CF
  Data.b $9D, $92, $D1, $0D, $C4, $20, $0C, $43, $2D, $E5, $9B, $5D, $22, $75, $FF, $1D
  Data.b $58, $80, $5D, $CE, $0E, $6E, $E1, $74, $1F, $D7, $36, $AA, $90, $79, $89, $49
  Data.b $5A, $8A, $E3, $37, $F0, $98, $DD, $54, $89, $B8, $C5, $5E, $9E, $57, $5B, $00
  Data.b $67, $A2, $04, $10, $89, $A1, $05, $95, $E6, $D3, $46, $47, $36, $F4, $28, $25
  Data.b $A6, $0A, $4A, $32, $22, $55, $8B, $B5, $0E, $4A, $B1, $01, $B4, $2E, $C6, $9D
  Data.b $A4, $30, $93, $CC, $88, $31, $8B, $5A, $2C, $2E, $C6, $9A, $2A, $33, $93, $57
  Data.b $BA, $72, $D3, $9B, $33, $AF, $1E, $38, $7B, $A4, $CD, $B0, $35, $3C, $F3, $C5
  Data.b $3C, $33, $0B, $DB, $60, $40, $4B, $F7, $BB, $C9, $5D, $3E, $19, $E2, $FC, $56
  Data.b $58, $71, $3C, $67, $63, $C6, $CE, $56, $8F, $7F, $E7, $D9, $BA, $98, $07, $F4
  Data.b $78, $BE, $CB, $2F, $AB, $59, $1A, $C5, $7E, $E7, $B9, $A1, $17, $FF, $E9, $8A
  Data.b $0F, $33, $D5, $8D, $0D, $67, $30, $E8, $C1, $00, $00, $00, $00, $49, $45, $4E
  Data.b $44, $AE, $42, $60, $82 
SKH:                                   ;PNG schwarzer Knig auf hellem Feld  
  Data.b $89, $50, $4E, $47, $0D, $0A, $1A, $0A, $00, $00, $00, $0D, $49, $48, $44, $52
  Data.b $00, $00, $00, $26, $00, $00, $00, $26, $04, $03, $00, $00, $00, $5A, $13, $F4
  Data.b $9D, $00, $00, $00, $01, $73, $52, $47, $42, $00, $AE, $CE, $1C, $E9, $00, $00
  Data.b $00, $04, $67, $41, $4D, $41, $00, $00, $B1, $8F, $0B, $FC, $61, $05, $00, $00
  Data.b $00, $20, $63, $48, $52, $4D, $00, $00, $7A, $26, $00, $00, $80, $84, $00, $00
  Data.b $FA, $00, $00, $00, $80, $E8, $00, $00, $75, $30, $00, $00, $EA, $60, $00, $00
  Data.b $3A, $98, $00, $00, $17, $70, $9C, $BA, $51, $3C, $00, $00, $00, $30, $50, $4C
  Data.b $54, $45, $00, $00, $00, $00, $00, $A4, $20, $AC, $20, $40, $80, $80, $FC, $00
  Data.b $00, $C0, $C0, $C0, $D8, $D8, $D8, $A0, $A0, $A0, $50, $50, $50, $50, $50, $FC
  Data.b $24, $EC, $24, $C8, $C8, $C8, $FC, $00, $00, $FC, $FC, $FC, $94, $94, $94, $FC
  Data.b $FC, $FC, $8C, $19, $28, $84, $00, $00, $00, $9A, $49, $44, $41, $54, $28, $CF
  Data.b $9D, $52, $DB, $11, $80, $30, $08, $CB, $02, $EC, $BF, $16, $0B, $64, $17, $1B
  Data.b $1E, $15, $CF, $0F, $1F, $5C, $AF, $D2, $84, $00, $A5, $82, $77, $C3, $67, $EC
  Data.b $A5, $E7, $B0, $57, $D8, $CF, $7C, $71, $04, $D0, $44, $38, $80, $39, $A8, $0D
  Data.b $41, $AF, $65, $0B, $76, $D3, $92, $27, $4C, $11, $12, $41, $42, $45, $EB, $28
  Data.b $09, $03, $A3, $92, $24, $71, $C9, $17, $32, $B1, $88, $AD, $9C, $8D, $AD, $98
  Data.b $08, $2B, $44, $5A, $34, $97, $5A, $4F, $5E, $35, $D0, $35, $BC, $C4, $28, $A9
  Data.b $55, $CF, $1B, $AB, $9E, $FB, $F6, $D8, $93, $C8, $19, $C4, $9D, $75, $D7, $9E
  Data.b $01, $B3, $60, $1A, $BF, $63, $3D, $E1, $81, $9D, $35, $9E, $F2, $71, $7C, $AB
  Data.b $D3, $7C, $14, $8E, $EE, $79, $91, $16, $E6, $05, $D9, $7C, $73, $1F, $D0, $8F
  Data.b $FF, $F4, $B4, $03, $1F, $FA, $94, $14, $0D, $12, $C9, $CC, $00, $00, $00, $00
  Data.b $49, $45, $4E, $44, $AE, $42, $60, $82  
EndDataSection

; IDE Options = PureBasic 5.50 (Windows - x64)
; CursorPosition = 1
; FirstLine = 60
; Folding = ---
; EnableAsm
; EnableOnError
; DisableDebugger